Chrome DevTools Protocol message model.
License
Licensed under either of
- Apache License, Version 2.0 (LICENSE-APACHE or http://www.apache.org/licenses/LICENSE-2.0)
- MIT license (LICENSE-MIT or http://opensource.org/licenses/MIT) at your option.
Contribution
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.!
Modules
- accessibility
AccessibilityandDOMandexperimental - animation
AnimationandDOMandexperimentalandRuntime - application_
cache ApplicationCacheandexperimentalandPage - audits
AuditsandexperimentalandNetwork - Audits domain allows investigation of page violations and possible improvements.
- background_
service BackgroundServiceandexperimental - Defines events for background web platform features.
- browser
Browser - The Browser domain defines methods and events for browser managing.
- cache_
storage CacheStorageandexperimental - cast
Castandexperimental - A domain for interacting with Cast, Presentation API, and Remote Playback API functionalities.
- console
Deprecated ConsoleandRuntime - This domain is deprecated - use Runtime or Log instead.
- css
CSSandDOMandexperimentalandPage - This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles)
have an associated
idused in subsequent operations on the related object. Each object type has a specificidstructure, and those are not interchangeable between objects of different kinds. CSS objects can be loaded using theget*ForNode()calls (which accept a DOM node id). A client can also keep track of stylesheets via thestyleSheetAdded/styleSheetRemovedevents and subsequently load the required stylesheet contents using thegetStyleSheet[Text]()methods. - database
Databaseandexperimental - debugger
DebuggerandRuntime - Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc.
- device_
orientation DeviceOrientationandexperimental - dom
DOMandRuntime - This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object
that has an
id. Thisidcan be used to get additional information on the Node, resolve it into the JavaScript object wrapper, etc. It is important that client receives DOM events only for the nodes that are known to the client. Backend keeps track of the nodes that were sent to the client and never sends the same node twice. It is client’s responsibility to collect information about the nodes that were sent to the client.Note that
iframeowner elements will return corresponding document elements as their child nodes. - dom_
debugger DebuggerandDOMandDOMDebuggerandRuntime - DOM debugging allows setting breakpoints on particular DOM operations and events. JavaScript execution will stop on these operations as if there was a regular breakpoint set.
- dom_
snapshot CSSandDOMandDOMDebuggerandDOMSnapshotandexperimentalandPage - This domain facilitates obtaining document snapshots with DOM, layout, and style information.
- dom_
storage DOMStorageandexperimental - Query and modify DOM storage.
- emulation
DOMandEmulationandPageandRuntime - This domain emulates different environments for the page.
- fetch
FetchandIOandNetworkandPage - A domain for letting clients substitute browser’s network layer with client code.
- headless_
experimental experimentalandHeadlessExperimentalandPageandRuntime - This domain provides experimental commands only supported in headless mode.
- heap_
profiler experimentalandHeapProfilerandRuntime - indexed_
db experimentalandIndexedDBandRuntime - input
Input - inspector
experimentalandInspector - io
IO - Input/Output operations for streams produced by DevTools.
- layer_
tree DOMandexperimentalandLayerTree - log
LogandNetworkandRuntime - Provides access to log entries.
- media
experimentalandMedia - This domain allows detailed inspection of media elements
- memory
experimentalandMemory - network
DebuggerandNetworkandRuntimeandSecurity - Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.
- overlay
DOMandexperimentalandOverlayandPageandRuntime - This domain provides various functionality related to drawing atop the inspected page.
- page
DebuggerandDOMandIOandNetworkandPageandRuntime - Actions and events related to the inspected page belong to the page domain.
- performance
Performance - performance_
timeline DOMandexperimentalandNetworkandPerformanceTimeline - Reporting of performance timeline events, as specified in https://w3c.github.io/performance-timeline/#dom-performanceobserver.
- profiler
DebuggerandProfilerandRuntime - runtime
Runtime - Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group.
- schema
Deprecated Schema - This domain is deprecated.
- security
Security - Security
- service_
worker experimentalandServiceWorkerandTarget - storage
BrowserandexperimentalandNetworkandStorage - system_
info experimentalandSystemInfo - The SystemInfo domain defines methods and events for querying low-level system information.
- target
Target - Supports additional targets discovery and allows to attach to them.
- tethering
experimentalandTethering - The Tethering domain defines methods and events for browser port binding.
- tracing
experimentalandIOandTracing - web_
audio experimentalandWebAudio - This domain allows inspection of Web Audio API. https://webaudio.github.io/web-audio-api/
- web_
authn experimentalandWebAuthn - This domain allows configuring virtual authenticators to test the WebAuthn API.
Structs
Enums
Constants
- VERSION
- Generating Chrome DevTools protocol version.
Traits
- Command
- Chrome DevTools Protocol Command.