Module chrome_remote_interface_model::application_cache [−][src]
This is supported on crate features
experimental and ApplicationCache and Page only.Structs
| ApplicationCache | Detailed application cache information. |
| ApplicationCacheBuilder | |
| ApplicationCacheResource | Detailed application cache resource information. |
| ApplicationCacheStatusUpdatedEvent | |
| EnableCommand | Enables application cache domain notifications. |
| EnableReturn | Enables application cache domain notifications. |
| FrameWithManifest | Frame identifier - manifest URL pair. |
| GetApplicationCacheForFrameCommand | Returns relevant application cache data for the document in given frame. |
| GetApplicationCacheForFrameReturn | Returns relevant application cache data for the document in given frame. |
| GetFramesWithManifestsCommand | Returns array of frame identifiers with manifest urls for each frame containing a document associated with some application cache. |
| GetFramesWithManifestsReturn | Returns array of frame identifiers with manifest urls for each frame containing a document associated with some application cache. |
| GetManifestForFrameCommand | Returns manifest URL for document in the given frame. |
| GetManifestForFrameReturn | Returns manifest URL for document in the given frame. |
| NetworkStateUpdatedEvent |