pub struct GetFramesWithManifestsCommand {}Available on crate features
experimental and ApplicationCache and Page only.Expand description
Returns array of frame identifiers with manifest urls for each frame containing a document associated with some application cache.
Implementations