Module chrome_remote_interface_model::background_service [−][src]
This is supported on crate features
experimental and BackgroundService only.Defines events for background web platform features.
Structs
| BackgroundServiceEvent | |
| BackgroundServiceEventBuilder | |
| BackgroundServiceEventReceivedEvent | Called with all existing backgroundServiceEvents when enabled, and all new events afterwards if enabled and recording. |
| ClearEventsCommand | Clears all stored data for the service. |
| ClearEventsReturn | Clears all stored data for the service. |
| EventMetadata | A key-value pair for additional event information to pass along. |
| RecordingStateChangedEvent | Called when the recording state for the service has been updated. |
| SetRecordingCommand | Set the recording state for the service. |
| SetRecordingReturn | Set the recording state for the service. |
| StartObservingCommand | Enables event updates for the service. |
| StartObservingReturn | Enables event updates for the service. |
| StopObservingCommand | Disables event updates for the service. |
| StopObservingReturn | Disables event updates for the service. |
Enums
| ServiceName |