Module chrome_remote_interface_model::browser[][src]

This is supported on crate feature Browser only.

The Browser domain defines methods and events for browser managing.

Structs

Boundsexperimental

Browser window bounds information

BoundsBuilderexperimental
BrowserContextIdexperimental
Bucketexperimental

Chrome histogram bucket.

CloseCommand

Close browser gracefully.

CloseReturn

Close browser gracefully.

CrashCommandexperimental

Crashes browser on the main thread.

CrashGpuProcessCommandexperimental

Crashes GPU process.

CrashGpuProcessReturnexperimental

Crashes GPU process.

CrashReturnexperimental

Crashes browser on the main thread.

ExecuteBrowserCommandCommandexperimental

Invoke custom browser commands used by telemetry.

ExecuteBrowserCommandReturnexperimental

Invoke custom browser commands used by telemetry.

GetBrowserCommandLineCommandexperimental

Returns the command line switches for the browser process if, and only if --enable-automation is on the commandline.

GetBrowserCommandLineReturnexperimental

Returns the command line switches for the browser process if, and only if --enable-automation is on the commandline.

GetHistogramCommandexperimental

Get a Chrome histogram by name.

GetHistogramReturnexperimental

Get a Chrome histogram by name.

GetHistogramsCommandexperimental

Get Chrome histograms.

GetHistogramsReturnexperimental

Get Chrome histograms.

GetVersionCommand

Returns version information.

GetVersionReturn

Returns version information.

GetVersionReturnBuilder
GetWindowBoundsCommandexperimental

Get position and size of the browser window.

GetWindowBoundsReturnexperimental

Get position and size of the browser window.

GetWindowForTargetCommandexperimental

Get the browser window that contains the devtools target.

GetWindowForTargetReturnexperimental

Get the browser window that contains the devtools target.

GrantPermissionsCommandexperimental

Grant specific permissions to the given origin and reject all others.

GrantPermissionsReturnexperimental

Grant specific permissions to the given origin and reject all others.

Histogramexperimental

Chrome histogram.

HistogramBuilderexperimental
PermissionDescriptorexperimental

Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dictdef-permissiondescriptor.

PermissionDescriptorBuilderexperimental
ResetPermissionsCommandexperimental

Reset all permission management for all origins.

ResetPermissionsReturnexperimental

Reset all permission management for all origins.

SetDockTileCommandexperimental

Set dock tile details, platform-specific.

SetDockTileReturnexperimental

Set dock tile details, platform-specific.

SetDownloadBehaviorCommandexperimental

Set the behavior when downloading a file.

SetDownloadBehaviorReturnexperimental

Set the behavior when downloading a file.

SetPermissionCommandexperimental

Set permission settings for given origin.

SetPermissionCommandBuilderexperimental
SetPermissionReturnexperimental

Set permission settings for given origin.

SetWindowBoundsCommandexperimental

Set position and/or size of the browser window.

SetWindowBoundsReturnexperimental

Set position and/or size of the browser window.

WindowIdexperimental

Enums

BrowserCommandIdexperimental
PermissionSettingexperimental
PermissionTypeexperimental
SetDownloadBehaviorCommandBehavior
WindowStateexperimental