pub struct ForcePseudoStateCommand { /* private fields */ }Available on crate features
experimental and CSS and DOM and Page only.Expand description
Ensures that the given node will have specified pseudo-classes whenever its style is computed by the browser.
Implementations