pub struct GetMatchedStylesForNodeReturn { /* private fields */ }Available on crate features
experimental and CSS and DOM and Page only.Expand description
Returns requested styles for a DOM node identified by nodeId.
Implementations
Sourceimpl GetMatchedStylesForNodeReturn
impl GetMatchedStylesForNodeReturn
pub fn builder() -> GetMatchedStylesForNodeReturnBuilder
Sourcepub fn inline_style(&self) -> Option<&CssStyle>
pub fn inline_style(&self) -> Option<&CssStyle>
Inline style for the specified DOM node.
Sourcepub fn attributes_style(&self) -> Option<&CssStyle>
pub fn attributes_style(&self) -> Option<&CssStyle>
Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
Sourcepub fn matched_css_rules(&self) -> Option<&Vec<RuleMatch>>
pub fn matched_css_rules(&self) -> Option<&Vec<RuleMatch>>
CSS rules matching this node, from all applicable stylesheets.
Sourcepub fn pseudo_elements(&self) -> Option<&Vec<PseudoElementMatches>>
pub fn pseudo_elements(&self) -> Option<&Vec<PseudoElementMatches>>
Pseudo style matches for this node.
Sourcepub fn inherited(&self) -> Option<&Vec<InheritedStyleEntry>>
pub fn inherited(&self) -> Option<&Vec<InheritedStyleEntry>>
A chain of inherited styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn css_keyframes_rules(&self) -> Option<&Vec<CssKeyframesRule>>
pub fn css_keyframes_rules(&self) -> Option<&Vec<CssKeyframesRule>>
A list of CSS keyframed animations matching this node.