pub struct SetBreakpointByUrlCommandBuilder { /* private fields */ }Available on crate features
Debugger and Runtime only.Implementations
Sourceimpl SetBreakpointByUrlCommandBuilder
impl SetBreakpointByUrlCommandBuilder
Sourcepub fn line_number(&mut self, v: u32) -> &mut Self
pub fn line_number(&mut self, v: u32) -> &mut Self
Line number to set breakpoint at.
Sourcepub fn url_regex(&mut self, v: String) -> &mut Self
pub fn url_regex(&mut self, v: String) -> &mut Self
Regex pattern for the URLs of the resources to set breakpoints on. Either url or
urlRegex must be specified.
Sourcepub fn script_hash(&mut self, v: String) -> &mut Self
pub fn script_hash(&mut self, v: String) -> &mut Self
Script hash of the resources to set breakpoint on.
Sourcepub fn column_number(&mut self, v: u32) -> &mut Self
pub fn column_number(&mut self, v: u32) -> &mut Self
Offset in the line to set breakpoint at.
Sourcepub fn condition(&mut self, v: String) -> &mut Self
pub fn condition(&mut self, v: String) -> &mut Self
Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true.
pub fn build(&mut self) -> Result<SetBreakpointByUrlCommand, &'static str>