pub struct DescribeNodeCommand { /* private fields */ }Available on crate features
DOM and Runtime only.Expand description
Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
Implementations
Sourceimpl DescribeNodeCommand
impl DescribeNodeCommand
pub fn builder() -> DescribeNodeCommandBuilder
Sourcepub fn backend_node_id(&self) -> Option<&BackendNodeId>
pub fn backend_node_id(&self) -> Option<&BackendNodeId>
Identifier of the backend node.
Sourcepub fn object_id(&self) -> Option<&RemoteObjectId>
pub fn object_id(&self) -> Option<&RemoteObjectId>
JavaScript object id of the node wrapper.