Module dom_snapshot

Module dom_snapshot 

Available on crate features CSS and DOM and DOMDebugger and DOMSnapshot and experimental and Page only.
This domain facilitates obtaining document snapshots with DOM, layout, and style information.

Structs

ArrayOfStrings
Index of the string in the strings table.
CaptureSnapshotCommand
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
CaptureSnapshotReturn
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
ComputedStyle
A subset of the full ComputedStyle as defined by the request whitelist.
DisableCommand
Disables DOM snapshot agent for the given page.
DisableReturn
Disables DOM snapshot agent for the given page.
DocumentSnapshot
Document snapshot.
DocumentSnapshotBuilder
DomNode
A Node in the DOM tree.
DomNodeBuilder
EnableCommand
Enables DOM snapshot agent for the given page.
EnableReturn
Enables DOM snapshot agent for the given page.
GetSnapshotCommandDeprecated
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
GetSnapshotCommandBuilderDeprecated
GetSnapshotReturnDeprecated
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
InlineTextBox
Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
LayoutTreeNode
Details of an element in the DOM tree with a LayoutObject.
LayoutTreeNodeBuilder
LayoutTreeSnapshot
Table of details of an element in the DOM tree with a LayoutObject.
LayoutTreeSnapshotBuilder
NameValue
A name/value pair.
NodeTreeSnapshot
Table containing nodes.
NodeTreeSnapshotBuilder
RareBooleanData
RareIntegerData
RareStringData
Data that is only present on rare nodes.
Rectangle
StringIndex
Index of the string in the strings table.
TextBoxSnapshot
Table of details of the post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
TextBoxSnapshotBuilder