Struct chrome_remote_interface_model::dom_snapshot::DocumentSnapshot[][src]

pub struct DocumentSnapshot { /* fields omitted */ }
This is supported on crate features experimental and DOMSnapshot and CSS and DOM and DOMDebugger and Page only.

Document snapshot.

Implementations

impl DocumentSnapshot[src]

pub fn builder() -> DocumentSnapshotBuilder[src]

pub fn document_url(&self) -> &StringIndex[src]

Document URL that Document or FrameOwner node points to.

pub fn title(&self) -> &StringIndex[src]

Document title.

pub fn base_url(&self) -> &StringIndex[src]

Base URL that Document or FrameOwner node uses for URL completion.

pub fn content_language(&self) -> &StringIndex[src]

Contains the document's content language.

pub fn encoding_name(&self) -> &StringIndex[src]

Contains the document's character set encoding.

pub fn public_id(&self) -> &StringIndex[src]

DocumentType node's publicId.

pub fn system_id(&self) -> &StringIndex[src]

DocumentType node's systemId.

pub fn frame_id(&self) -> &StringIndex[src]

Frame ID for frame owner elements and also for the document node.

pub fn nodes(&self) -> &NodeTreeSnapshot[src]

A table with dom nodes.

pub fn layout(&self) -> &LayoutTreeSnapshot[src]

The nodes in the layout tree.

pub fn text_boxes(&self) -> &TextBoxSnapshot[src]

The post-layout inline text nodes.

pub fn scroll_offset_x(&self) -> Option<&f64>[src]

Horizontal scroll offset.

pub fn scroll_offset_y(&self) -> Option<&f64>[src]

Vertical scroll offset.

pub fn content_width(&self) -> Option<&f64>[src]

Document content width.

pub fn content_height(&self) -> Option<&f64>[src]

Document content height.