Struct chrome_remote_interface_model::dom_snapshot::LayoutTreeNodeBuilder[][src]

pub struct LayoutTreeNodeBuilder { /* fields omitted */ }
This is supported on crate features experimental and DOMSnapshot and CSS and DOM and DOMDebugger and Page only.

Implementations

impl LayoutTreeNodeBuilder[src]

pub fn dom_node_index(&mut self, v: u32) -> &mut Self[src]

The index of the related DOM node in the domNodes array returned by getSnapshot.

pub fn bounding_box(&mut self, v: Rect) -> &mut Self[src]

The bounding box in document coordinates. Note that scroll offset of the document is ignored.

pub fn layout_text(&mut self, v: String) -> &mut Self[src]

Contents of the LayoutText, if any.

pub fn inline_text_nodes(&mut self, v: Vec<InlineTextBox>) -> &mut Self[src]

The post-layout inline text nodes, if any.

pub fn style_index(&mut self, v: u32) -> &mut Self[src]

Index into the computedStyles array returned by getSnapshot.

pub fn paint_order(&mut self, v: u32) -> &mut Self[src]

Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.

pub fn is_stacking_context(&mut self, v: bool) -> &mut Self[src]

Set to true to indicate the element begins a new stacking context.

pub fn build(&mut self) -> Result<LayoutTreeNode, &'static str>[src]