Module chrome_remote_interface_model::emulation [−][src]
Emulation and DOM and Page and Runtime only.This domain emulates different environments for the page.
Structs
| CanEmulateCommand | Tells whether emulation is supported. |
| CanEmulateReturn | Tells whether emulation is supported. |
| ClearDeviceMetricsOverrideCommand | Clears the overriden device metrics. |
| ClearDeviceMetricsOverrideReturn | Clears the overriden device metrics. |
| ClearGeolocationOverrideCommand | Clears the overriden Geolocation Position and Error. |
| ClearGeolocationOverrideReturn | Clears the overriden Geolocation Position and Error. |
| ClearIdleOverrideCommand | experimentalClears Idle state overrides. |
| ClearIdleOverrideReturn | experimentalClears Idle state overrides. |
| DisplayFeature | |
| MediaFeature | |
| ResetPageScaleFactorCommand | experimentalRequests that page scale factor is reset to initial values. |
| ResetPageScaleFactorReturn | experimentalRequests that page scale factor is reset to initial values. |
| ScreenOrientation | Screen orientation. |
| SetCpuThrottlingRateCommand | experimentalEnables CPU throttling to emulate slow CPUs. |
| SetCpuThrottlingRateReturn | experimentalEnables CPU throttling to emulate slow CPUs. |
| SetDefaultBackgroundColorOverrideCommand | Sets or clears an override of the default background color of the frame. This override is used if the content does not specify one. |
| SetDefaultBackgroundColorOverrideReturn | Sets or clears an override of the default background color of the frame. This override is used if the content does not specify one. |
| SetDeviceMetricsOverrideCommand | Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and "device-width"/"device-height"-related CSS media query results). |
| SetDeviceMetricsOverrideCommandBuilder | |
| SetDeviceMetricsOverrideReturn | Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and "device-width"/"device-height"-related CSS media query results). |
| SetDisabledImageTypesCommand | experimental |
| SetDisabledImageTypesReturn | experimental |
| SetDocumentCookieDisabledCommand | experimental |
| SetDocumentCookieDisabledReturn | experimental |
| SetEmitTouchEventsForMouseCommand | experimental |
| SetEmitTouchEventsForMouseReturn | experimental |
| SetEmulatedMediaCommand | Emulates the given media type or media feature for CSS media queries. |
| SetEmulatedMediaReturn | Emulates the given media type or media feature for CSS media queries. |
| SetEmulatedVisionDeficiencyCommand | experimentalEmulates the given vision deficiency. |
| SetEmulatedVisionDeficiencyReturn | experimentalEmulates the given vision deficiency. |
| SetFocusEmulationEnabledCommand | experimentalEnables or disables simulating a focused and active page. |
| SetFocusEmulationEnabledReturn | experimentalEnables or disables simulating a focused and active page. |
| SetGeolocationOverrideCommand | Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable. |
| SetGeolocationOverrideReturn | Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable. |
| SetIdleOverrideCommand | experimentalOverrides the Idle state. |
| SetIdleOverrideReturn | experimentalOverrides the Idle state. |
| SetLocaleOverrideCommand | experimentalOverrides default host system locale with the specified one. |
| SetLocaleOverrideReturn | experimentalOverrides default host system locale with the specified one. |
| SetNavigatorOverridesCommand | DeprecatedexperimentalOverrides value returned by the javascript navigator object. |
| SetNavigatorOverridesReturn | DeprecatedexperimentalOverrides value returned by the javascript navigator object. |
| SetPageScaleFactorCommand | experimentalSets a specified page scale factor. |
| SetPageScaleFactorReturn | experimentalSets a specified page scale factor. |
| SetScriptExecutionDisabledCommand | Switches script execution in the page. |
| SetScriptExecutionDisabledReturn | Switches script execution in the page. |
| SetScrollbarsHiddenCommand | experimental |
| SetScrollbarsHiddenReturn | experimental |
| SetTimezoneOverrideCommand | experimentalOverrides default host system timezone with the specified one. |
| SetTimezoneOverrideReturn | experimentalOverrides default host system timezone with the specified one. |
| SetTouchEmulationEnabledCommand | Enables touch on platforms which do not support them. |
| SetTouchEmulationEnabledReturn | Enables touch on platforms which do not support them. |
| SetUserAgentOverrideCommand | Allows overriding user agent with the given string. |
| SetUserAgentOverrideCommandBuilder | |
| SetUserAgentOverrideReturn | Allows overriding user agent with the given string. |
| SetVirtualTimePolicyCommand | experimentalTurns on virtual time for all frames (replacing real-time with a synthetic time source) and sets the current virtual time policy. Note this supersedes any previous time budget. |
| SetVirtualTimePolicyCommandBuilder | experimental |
| SetVirtualTimePolicyReturn | experimentalTurns on virtual time for all frames (replacing real-time with a synthetic time source) and sets the current virtual time policy. Note this supersedes any previous time budget. |
| SetVisibleSizeCommand | DeprecatedexperimentalResizes the frame/viewport of the page. Note that this does not affect the frame's container (e.g. browser window). Can be used to produce screenshots of the specified size. Not supported on Android. |
| SetVisibleSizeReturn | DeprecatedexperimentalResizes the frame/viewport of the page. Note that this does not affect the frame's container (e.g. browser window). Can be used to produce screenshots of the specified size. Not supported on Android. |
| UserAgentBrandVersion | experimentalUsed to specify User Agent Cient Hints to emulate. See https://wicg.github.io/ua-client-hints |
| UserAgentMetadata | experimentalUsed to specify User Agent Cient Hints to emulate. See https://wicg.github.io/ua-client-hints |
| UserAgentMetadataBuilder | experimental |
| VirtualTimeBudgetExpiredEvent | experimentalNotification sent after the virtual time budget for the current VirtualTimePolicy has run out. |
Enums
| DisabledImageType | experimental |
| DisplayFeatureOrientation | |
| ScreenOrientationType | |
| SetEmitTouchEventsForMouseCommandConfiguration | |
| SetEmulatedVisionDeficiencyCommandType | |
| VirtualTimePolicy | experimental |