pub enum Event {
Show 163 variants
AnimationAnimationCanceled(AnimationCanceledEvent),
AnimationAnimationCreated(AnimationCreatedEvent),
AnimationAnimationStarted(AnimationStartedEvent),
ApplicationCacheApplicationCacheStatusUpdated(ApplicationCacheStatusUpdatedEvent),
ApplicationCacheNetworkStateUpdated(NetworkStateUpdatedEvent),
AuditsIssueAdded(IssueAddedEvent),
BackgroundServiceRecordingStateChanged(RecordingStateChangedEvent),
BackgroundServiceBackgroundServiceEventReceived(BackgroundServiceEventReceivedEvent),
BrowserDownloadWillBegin(DownloadWillBeginEvent),
BrowserDownloadProgress(DownloadProgressEvent),
CssFontsUpdated(FontsUpdatedEvent),
CssMediaQueryResultChanged(MediaQueryResultChangedEvent),
CssStyleSheetAdded(StyleSheetAddedEvent),
CssStyleSheetChanged(StyleSheetChangedEvent),
CssStyleSheetRemoved(StyleSheetRemovedEvent),
CastSinksUpdated(SinksUpdatedEvent),
CastIssueUpdated(IssueUpdatedEvent),
DomAttributeModified(AttributeModifiedEvent),
DomAttributeRemoved(AttributeRemovedEvent),
DomCharacterDataModified(CharacterDataModifiedEvent),
DomChildNodeCountUpdated(ChildNodeCountUpdatedEvent),
DomChildNodeInserted(ChildNodeInsertedEvent),
DomChildNodeRemoved(ChildNodeRemovedEvent),
DomDistributedNodesUpdated(DistributedNodesUpdatedEvent),
DomDocumentUpdated(DocumentUpdatedEvent),
DomInlineStyleInvalidated(InlineStyleInvalidatedEvent),
DomPseudoElementAdded(PseudoElementAddedEvent),
DomPseudoElementRemoved(PseudoElementRemovedEvent),
DomSetChildNodes(SetChildNodesEvent),
DomShadowRootPopped(ShadowRootPoppedEvent),
DomShadowRootPushed(ShadowRootPushedEvent),
DomStorageDomStorageItemAdded(DomStorageItemAddedEvent),
DomStorageDomStorageItemRemoved(DomStorageItemRemovedEvent),
DomStorageDomStorageItemUpdated(DomStorageItemUpdatedEvent),
DomStorageDomStorageItemsCleared(DomStorageItemsClearedEvent),
DatabaseAddDatabase(AddDatabaseEvent),
EmulationVirtualTimeBudgetExpired(VirtualTimeBudgetExpiredEvent),
HeadlessExperimentalNeedsBeginFramesChanged(NeedsBeginFramesChangedEvent),
InputDragIntercepted(DragInterceptedEvent),
InspectorDetached(DetachedEvent),
InspectorTargetCrashed(TargetCrashedEvent),
InspectorTargetReloadedAfterCrash(TargetReloadedAfterCrashEvent),
LayerTreeLayerPainted(LayerPaintedEvent),
LayerTreeLayerTreeDidChange(LayerTreeDidChangeEvent),
LogEntryAdded(EntryAddedEvent),
NetworkDataReceived(DataReceivedEvent),
NetworkEventSourceMessageReceived(EventSourceMessageReceivedEvent),
NetworkLoadingFailed(LoadingFailedEvent),
NetworkLoadingFinished(LoadingFinishedEvent),
NetworkRequestIntercepted(RequestInterceptedEvent),
NetworkRequestServedFromCache(RequestServedFromCacheEvent),
NetworkRequestWillBeSent(RequestWillBeSentEvent),
NetworkResourceChangedPriority(ResourceChangedPriorityEvent),
NetworkSignedExchangeReceived(SignedExchangeReceivedEvent),
NetworkResponseReceived(ResponseReceivedEvent),
NetworkWebSocketClosed(WebSocketClosedEvent),
NetworkWebSocketCreated(WebSocketCreatedEvent),
NetworkWebSocketFrameError(WebSocketFrameErrorEvent),
NetworkWebSocketFrameReceived(WebSocketFrameReceivedEvent),
NetworkWebSocketFrameSent(WebSocketFrameSentEvent),
NetworkWebSocketHandshakeResponseReceived(WebSocketHandshakeResponseReceivedEvent),
NetworkWebSocketWillSendHandshakeRequest(WebSocketWillSendHandshakeRequestEvent),
NetworkWebTransportCreated(WebTransportCreatedEvent),
NetworkWebTransportConnectionEstablished(WebTransportConnectionEstablishedEvent),
NetworkWebTransportClosed(WebTransportClosedEvent),
NetworkRequestWillBeSentExtraInfo(RequestWillBeSentExtraInfoEvent),
NetworkResponseReceivedExtraInfo(ResponseReceivedExtraInfoEvent),
NetworkTrustTokenOperationDone(TrustTokenOperationDoneEvent),
OverlayInspectNodeRequested(InspectNodeRequestedEvent),
OverlayNodeHighlightRequested(NodeHighlightRequestedEvent),
OverlayScreenshotRequested(ScreenshotRequestedEvent),
OverlayInspectModeCanceled(InspectModeCanceledEvent),
PageDomContentEventFired(DomContentEventFiredEvent),
PageFileChooserOpened(FileChooserOpenedEvent),
PageFrameAttached(FrameAttachedEvent),
PageFrameClearedScheduledNavigation(FrameClearedScheduledNavigationEvent),
PageFrameDetached(FrameDetachedEvent),
PageFrameNavigated(FrameNavigatedEvent),
PageDocumentOpened(DocumentOpenedEvent),
PageFrameResized(FrameResizedEvent),
PageFrameRequestedNavigation(FrameRequestedNavigationEvent),
PageFrameScheduledNavigation(FrameScheduledNavigationEvent),
PageFrameStartedLoading(FrameStartedLoadingEvent),
PageFrameStoppedLoading(FrameStoppedLoadingEvent),
PageDownloadWillBegin(DownloadWillBeginEvent),
PageDownloadProgress(DownloadProgressEvent),
PageInterstitialHidden(InterstitialHiddenEvent),
PageInterstitialShown(InterstitialShownEvent),
PageJavascriptDialogClosed(JavascriptDialogClosedEvent),
PageJavascriptDialogOpening(JavascriptDialogOpeningEvent),
PageLifecycleEvent(LifecycleEventEvent),
PageLoadEventFired(LoadEventFiredEvent),
PageNavigatedWithinDocument(NavigatedWithinDocumentEvent),
PageScreencastFrame(ScreencastFrameEvent),
PageScreencastVisibilityChanged(ScreencastVisibilityChangedEvent),
PageWindowOpen(WindowOpenEvent),
PageCompilationCacheProduced(CompilationCacheProducedEvent),
PerformanceMetrics(MetricsEvent),
PerformanceTimelineTimelineEventAdded(TimelineEventAddedEvent),
SecurityCertificateError(CertificateErrorEvent),
SecurityVisibleSecurityStateChanged(VisibleSecurityStateChangedEvent),
SecuritySecurityStateChanged(SecurityStateChangedEvent),
ServiceWorkerWorkerErrorReported(WorkerErrorReportedEvent),
ServiceWorkerWorkerRegistrationUpdated(WorkerRegistrationUpdatedEvent),
ServiceWorkerWorkerVersionUpdated(WorkerVersionUpdatedEvent),
StorageCacheStorageContentUpdated(CacheStorageContentUpdatedEvent),
StorageCacheStorageListUpdated(CacheStorageListUpdatedEvent),
StorageIndexedDbContentUpdated(IndexedDbContentUpdatedEvent),
StorageIndexedDbListUpdated(IndexedDbListUpdatedEvent),
TargetAttachedToTarget(AttachedToTargetEvent),
TargetDetachedFromTarget(DetachedFromTargetEvent),
TargetReceivedMessageFromTarget(ReceivedMessageFromTargetEvent),
TargetTargetCreated(TargetCreatedEvent),
TargetTargetDestroyed(TargetDestroyedEvent),
TargetTargetCrashed(TargetCrashedEvent),
TargetTargetInfoChanged(TargetInfoChangedEvent),
TetheringAccepted(AcceptedEvent),
TracingBufferUsage(BufferUsageEvent),
TracingDataCollected(DataCollectedEvent),
TracingTracingComplete(TracingCompleteEvent),
FetchRequestPaused(RequestPausedEvent),
FetchAuthRequired(AuthRequiredEvent),
WebAudioContextCreated(ContextCreatedEvent),
WebAudioContextWillBeDestroyed(ContextWillBeDestroyedEvent),
WebAudioContextChanged(ContextChangedEvent),
WebAudioAudioListenerCreated(AudioListenerCreatedEvent),
WebAudioAudioListenerWillBeDestroyed(AudioListenerWillBeDestroyedEvent),
WebAudioAudioNodeCreated(AudioNodeCreatedEvent),
WebAudioAudioNodeWillBeDestroyed(AudioNodeWillBeDestroyedEvent),
WebAudioAudioParamCreated(AudioParamCreatedEvent),
WebAudioAudioParamWillBeDestroyed(AudioParamWillBeDestroyedEvent),
WebAudioNodesConnected(NodesConnectedEvent),
WebAudioNodesDisconnected(NodesDisconnectedEvent),
WebAudioNodeParamConnected(NodeParamConnectedEvent),
WebAudioNodeParamDisconnected(NodeParamDisconnectedEvent),
MediaPlayerPropertiesChanged(PlayerPropertiesChangedEvent),
MediaPlayerEventsAdded(PlayerEventsAddedEvent),
MediaPlayerMessagesLogged(PlayerMessagesLoggedEvent),
MediaPlayerErrorsRaised(PlayerErrorsRaisedEvent),
MediaPlayersCreated(PlayersCreatedEvent),
ConsoleMessageAdded(MessageAddedEvent),
DebuggerBreakpointResolved(BreakpointResolvedEvent),
DebuggerPaused(PausedEvent),
DebuggerResumed(ResumedEvent),
DebuggerScriptFailedToParse(ScriptFailedToParseEvent),
DebuggerScriptParsed(ScriptParsedEvent),
HeapProfilerAddHeapSnapshotChunk(AddHeapSnapshotChunkEvent),
HeapProfilerHeapStatsUpdate(HeapStatsUpdateEvent),
HeapProfilerLastSeenObjectId(LastSeenObjectIdEvent),
HeapProfilerReportHeapSnapshotProgress(ReportHeapSnapshotProgressEvent),
HeapProfilerResetProfiles(ResetProfilesEvent),
ProfilerConsoleProfileFinished(ConsoleProfileFinishedEvent),
ProfilerConsoleProfileStarted(ConsoleProfileStartedEvent),
ProfilerPreciseCoverageDeltaUpdate(PreciseCoverageDeltaUpdateEvent),
RuntimeBindingCalled(BindingCalledEvent),
RuntimeConsoleApiCalled(ConsoleApiCalledEvent),
RuntimeExceptionRevoked(ExceptionRevokedEvent),
RuntimeExceptionThrown(ExceptionThrownEvent),
RuntimeExecutionContextCreated(ExecutionContextCreatedEvent),
RuntimeExecutionContextDestroyed(ExecutionContextDestroyedEvent),
RuntimeExecutionContextsCleared(ExecutionContextsClearedEvent),
RuntimeInspectRequested(InspectRequestedEvent),
Unknown(String, Value),
}Expand description
Chrome DevTools Protocol event.
Variants
AnimationAnimationCanceled(AnimationCanceledEvent)
Animation and DOM and experimental and Runtime only.Event for when an animation has been cancelled.
AnimationAnimationCreated(AnimationCreatedEvent)
Animation and DOM and experimental and Runtime only.Event for each animation that has been created.
AnimationAnimationStarted(AnimationStartedEvent)
Animation and DOM and experimental and Runtime only.Event for animation that has been started.
ApplicationCacheApplicationCacheStatusUpdated(ApplicationCacheStatusUpdatedEvent)
ApplicationCache and experimental and Page only.ApplicationCacheNetworkStateUpdated(NetworkStateUpdatedEvent)
ApplicationCache and experimental and Page only.AuditsIssueAdded(IssueAddedEvent)
Audits and experimental and Network only.BackgroundServiceRecordingStateChanged(RecordingStateChangedEvent)
BackgroundService and experimental only.Called when the recording state for the service has been updated.
BackgroundServiceBackgroundServiceEventReceived(BackgroundServiceEventReceivedEvent)
BackgroundService and experimental only.Called with all existing backgroundServiceEvents when enabled, and all new events afterwards if enabled and recording.
BrowserDownloadWillBegin(DownloadWillBeginEvent)
Browser and experimental only.Fired when page is about to start a download.
BrowserDownloadProgress(DownloadProgressEvent)
Browser and experimental only.Fired when download makes progress. Last call has |done| == true.
CssFontsUpdated(FontsUpdatedEvent)
CSS and DOM and experimental and Page only.Fires whenever a web font is updated. A non-empty font parameter indicates a successfully loaded web font
CssMediaQueryResultChanged(MediaQueryResultChangedEvent)
CSS and DOM and experimental and Page only.Fires whenever a MediaQuery result changes (for example, after a browser window has been resized.) The current implementation considers only viewport-dependent media features.
CssStyleSheetAdded(StyleSheetAddedEvent)
CSS and DOM and experimental and Page only.Fired whenever an active document stylesheet is added.
CssStyleSheetChanged(StyleSheetChangedEvent)
CSS and DOM and experimental and Page only.Fired whenever a stylesheet is changed as a result of the client operation.
CssStyleSheetRemoved(StyleSheetRemovedEvent)
CSS and DOM and experimental and Page only.Fired whenever an active document stylesheet is removed.
CastSinksUpdated(SinksUpdatedEvent)
Cast and experimental only.This is fired whenever the list of available sinks changes. A sink is a device or a software surface that you can cast to.
CastIssueUpdated(IssueUpdatedEvent)
Cast and experimental only.This is fired whenever the outstanding issue/error message changes. |issueMessage| is empty if there is no issue.
DomAttributeModified(AttributeModifiedEvent)
DOM and Runtime only.Fired when Element’s attribute is modified.
DomAttributeRemoved(AttributeRemovedEvent)
DOM and Runtime only.Fired when Element’s attribute is removed.
DomCharacterDataModified(CharacterDataModifiedEvent)
DOM and Runtime only.Mirrors DOMCharacterDataModified event.
DomChildNodeCountUpdated(ChildNodeCountUpdatedEvent)
DOM and Runtime only.Fired when Container’s child node count has changed.
DomChildNodeInserted(ChildNodeInsertedEvent)
DOM and Runtime only.Mirrors DOMNodeInserted event.
DomChildNodeRemoved(ChildNodeRemovedEvent)
DOM and Runtime only.Mirrors DOMNodeRemoved event.
DomDistributedNodesUpdated(DistributedNodesUpdatedEvent)
DOM and experimental and Runtime only.Called when distrubution is changed.
DomDocumentUpdated(DocumentUpdatedEvent)
DOM and Runtime only.Fired when Document has been totally updated. Node ids are no longer valid.
DomInlineStyleInvalidated(InlineStyleInvalidatedEvent)
DOM and experimental and Runtime only.Fired when Element’s inline style is modified via a CSS property modification.
DomPseudoElementAdded(PseudoElementAddedEvent)
DOM and experimental and Runtime only.Called when a pseudo element is added to an element.
DomPseudoElementRemoved(PseudoElementRemovedEvent)
DOM and experimental and Runtime only.Called when a pseudo element is removed from an element.
DomSetChildNodes(SetChildNodesEvent)
DOM and Runtime only.Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids.
DomShadowRootPopped(ShadowRootPoppedEvent)
DOM and experimental and Runtime only.Called when shadow root is popped from the element.
DomShadowRootPushed(ShadowRootPushedEvent)
DOM and experimental and Runtime only.Called when shadow root is pushed into the element.
DomStorageDomStorageItemAdded(DomStorageItemAddedEvent)
DOMStorage and experimental only.DomStorageDomStorageItemRemoved(DomStorageItemRemovedEvent)
DOMStorage and experimental only.DomStorageDomStorageItemUpdated(DomStorageItemUpdatedEvent)
DOMStorage and experimental only.DomStorageDomStorageItemsCleared(DomStorageItemsClearedEvent)
DOMStorage and experimental only.DatabaseAddDatabase(AddDatabaseEvent)
Database and experimental only.EmulationVirtualTimeBudgetExpired(VirtualTimeBudgetExpiredEvent)
DOM and Emulation and experimental and Page and Runtime only.Notification sent after the virtual time budget for the current VirtualTimePolicy has run out.
HeadlessExperimentalNeedsBeginFramesChanged(NeedsBeginFramesChangedEvent)
experimental and HeadlessExperimental and Page and Runtime only.Issued when the target starts or stops needing BeginFrames. Deprecated. Issue beginFrame unconditionally instead and use result from beginFrame to detect whether the frames were suppressed.
InputDragIntercepted(DragInterceptedEvent)
experimental and Input only.Emitted only when Input.setInterceptDrags is enabled. Use this data with Input.dispatchDragEvent to
restore normal drag and drop behavior.
InspectorDetached(DetachedEvent)
experimental and Inspector only.Fired when remote debugging connection is about to be terminated. Contains detach reason.
InspectorTargetCrashed(TargetCrashedEvent)
experimental and Inspector only.Fired when debugging target has crashed
InspectorTargetReloadedAfterCrash(TargetReloadedAfterCrashEvent)
experimental and Inspector only.Fired when debugging target has reloaded after crash
LayerTreeLayerPainted(LayerPaintedEvent)
DOM and experimental and LayerTree only.LayerTreeLayerTreeDidChange(LayerTreeDidChangeEvent)
DOM and experimental and LayerTree only.LogEntryAdded(EntryAddedEvent)
Log and Network and Runtime only.Issued when new message was logged.
NetworkDataReceived(DataReceivedEvent)
Debugger and Network and Runtime and Security only.Fired when data chunk was received over the network.
NetworkEventSourceMessageReceived(EventSourceMessageReceivedEvent)
Debugger and Network and Runtime and Security only.Fired when EventSource message is received.
NetworkLoadingFailed(LoadingFailedEvent)
Debugger and Network and Runtime and Security only.Fired when HTTP request has failed to load.
NetworkLoadingFinished(LoadingFinishedEvent)
Debugger and Network and Runtime and Security only.Fired when HTTP request has finished loading.
NetworkRequestIntercepted(RequestInterceptedEvent)
Debugger and experimental and Network and Runtime and Security only.Details of an intercepted HTTP request, which must be either allowed, blocked, modified or mocked. Deprecated, use Fetch.requestPaused instead.
NetworkRequestServedFromCache(RequestServedFromCacheEvent)
Debugger and Network and Runtime and Security only.Fired if request ended up loading from cache.
NetworkRequestWillBeSent(RequestWillBeSentEvent)
Debugger and Network and Runtime and Security only.Fired when page is about to send HTTP request.
NetworkResourceChangedPriority(ResourceChangedPriorityEvent)
Debugger and experimental and Network and Runtime and Security only.Fired when resource loading priority is changed
NetworkSignedExchangeReceived(SignedExchangeReceivedEvent)
Debugger and experimental and Network and Runtime and Security only.Fired when a signed exchange was received over the network
NetworkResponseReceived(ResponseReceivedEvent)
Debugger and Network and Runtime and Security only.Fired when HTTP response is available.
NetworkWebSocketClosed(WebSocketClosedEvent)
Debugger and Network and Runtime and Security only.Fired when WebSocket is closed.
NetworkWebSocketCreated(WebSocketCreatedEvent)
Debugger and Network and Runtime and Security only.Fired upon WebSocket creation.
NetworkWebSocketFrameError(WebSocketFrameErrorEvent)
Debugger and Network and Runtime and Security only.Fired when WebSocket message error occurs.
NetworkWebSocketFrameReceived(WebSocketFrameReceivedEvent)
Debugger and Network and Runtime and Security only.Fired when WebSocket message is received.
NetworkWebSocketFrameSent(WebSocketFrameSentEvent)
Debugger and Network and Runtime and Security only.Fired when WebSocket message is sent.
NetworkWebSocketHandshakeResponseReceived(WebSocketHandshakeResponseReceivedEvent)
Debugger and Network and Runtime and Security only.Fired when WebSocket handshake response becomes available.
NetworkWebSocketWillSendHandshakeRequest(WebSocketWillSendHandshakeRequestEvent)
Debugger and Network and Runtime and Security only.Fired when WebSocket is about to initiate handshake.
NetworkWebTransportCreated(WebTransportCreatedEvent)
Debugger and Network and Runtime and Security only.Fired upon WebTransport creation.
NetworkWebTransportConnectionEstablished(WebTransportConnectionEstablishedEvent)
Debugger and Network and Runtime and Security only.Fired when WebTransport handshake is finished.
NetworkWebTransportClosed(WebTransportClosedEvent)
Debugger and Network and Runtime and Security only.Fired when WebTransport is disposed.
NetworkRequestWillBeSentExtraInfo(RequestWillBeSentExtraInfoEvent)
Debugger and experimental and Network and Runtime and Security only.Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request.
NetworkResponseReceivedExtraInfo(ResponseReceivedExtraInfoEvent)
Debugger and experimental and Network and Runtime and Security only.Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived.
NetworkTrustTokenOperationDone(TrustTokenOperationDoneEvent)
Debugger and experimental and Network and Runtime and Security only.Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received.
OverlayInspectNodeRequested(InspectNodeRequestedEvent)
DOM and experimental and Overlay and Page and Runtime only.Fired when the node should be inspected. This happens after call to setInspectMode or when
user manually inspects an element.
OverlayNodeHighlightRequested(NodeHighlightRequestedEvent)
DOM and experimental and Overlay and Page and Runtime only.Fired when the node should be highlighted. This happens after call to setInspectMode.
OverlayScreenshotRequested(ScreenshotRequestedEvent)
DOM and experimental and Overlay and Page and Runtime only.Fired when user asks to capture screenshot of some area on the page.
OverlayInspectModeCanceled(InspectModeCanceledEvent)
DOM and experimental and Overlay and Page and Runtime only.Fired when user cancels the inspect mode.
PageDomContentEventFired(DomContentEventFiredEvent)
Debugger and DOM and IO and Network and Page and Runtime only.PageFileChooserOpened(FileChooserOpenedEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Emitted only when page.interceptFileChooser is enabled.
PageFrameAttached(FrameAttachedEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when frame has been attached to its parent.
Debugger and DOM and IO and Network and Page and Runtime only.Fired when frame no longer has a scheduled navigation.
PageFrameDetached(FrameDetachedEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when frame has been detached from its parent.
Debugger and DOM and IO and Network and Page and Runtime only.Fired once navigation of the frame has completed. Frame is now associated with the new loader.
PageDocumentOpened(DocumentOpenedEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when opening document to write to.
PageFrameResized(FrameResizedEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when a renderer-initiated navigation is requested. Navigation may still be cancelled after the event is issued.
Debugger and DOM and IO and Network and Page and Runtime only.Fired when frame schedules a potential navigation.
PageFrameStartedLoading(FrameStartedLoadingEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when frame has started loading.
PageFrameStoppedLoading(FrameStoppedLoadingEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when frame has stopped loading.
PageDownloadWillBegin(DownloadWillBeginEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when page is about to start a download. Deprecated. Use Browser.downloadWillBegin instead.
PageDownloadProgress(DownloadProgressEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when download makes progress. Last call has |done| == true. Deprecated. Use Browser.downloadProgress instead.
PageInterstitialHidden(InterstitialHiddenEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when interstitial page was hidden
PageInterstitialShown(InterstitialShownEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when interstitial page was shown
PageJavascriptDialogClosed(JavascriptDialogClosedEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been closed.
PageJavascriptDialogOpening(JavascriptDialogOpeningEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open.
PageLifecycleEvent(LifecycleEventEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired for top level page lifecycle events such as navigation, load, paint, etc.
PageLoadEventFired(LoadEventFiredEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation.
PageScreencastFrame(ScreencastFrameEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Compressed image data requested by the startScreencast.
PageScreencastVisibilityChanged(ScreencastVisibilityChangedEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Fired when the page with currently enabled screencast was shown or hidden `.
PageWindowOpen(WindowOpenEvent)
Debugger and DOM and IO and Network and Page and Runtime only.Fired when a new window is going to be opened, via window.open(), link click, form submission, etc.
PageCompilationCacheProduced(CompilationCacheProducedEvent)
Debugger and DOM and experimental and IO and Network and Page and Runtime only.Issued for every compilation cache generated. Is only available if Page.setGenerateCompilationCache is enabled.
PerformanceMetrics(MetricsEvent)
Performance only.Current values of the metrics.
PerformanceTimelineTimelineEventAdded(TimelineEventAddedEvent)
DOM and experimental and Network and PerformanceTimeline only.Sent when a performance timeline event is added. See reportPerformanceTimeline method.
SecurityCertificateError(CertificateErrorEvent)
Security only.There is a certificate error. If overriding certificate errors is enabled, then it should be
handled with the handleCertificateError command. Note: this event does not fire if the
certificate error has been allowed internally. Only one client per target should override
certificate errors at the same time.
SecurityVisibleSecurityStateChanged(VisibleSecurityStateChangedEvent)
experimental and Security only.The security state of the page changed.
SecuritySecurityStateChanged(SecurityStateChangedEvent)
Security only.The security state of the page changed.
ServiceWorkerWorkerErrorReported(WorkerErrorReportedEvent)
experimental and ServiceWorker and Target only.ServiceWorkerWorkerRegistrationUpdated(WorkerRegistrationUpdatedEvent)
experimental and ServiceWorker and Target only.ServiceWorkerWorkerVersionUpdated(WorkerVersionUpdatedEvent)
experimental and ServiceWorker and Target only.StorageCacheStorageContentUpdated(CacheStorageContentUpdatedEvent)
Browser and experimental and Network and Storage only.A cache’s contents have been modified.
StorageCacheStorageListUpdated(CacheStorageListUpdatedEvent)
Browser and experimental and Network and Storage only.A cache has been added/deleted.
StorageIndexedDbContentUpdated(IndexedDbContentUpdatedEvent)
Browser and experimental and Network and Storage only.The origin’s IndexedDB object store has been modified.
StorageIndexedDbListUpdated(IndexedDbListUpdatedEvent)
Browser and experimental and Network and Storage only.The origin’s IndexedDB database list has been modified.
TargetAttachedToTarget(AttachedToTargetEvent)
experimental and Target only.Issued when attached to target because of auto-attach or attachToTarget command.
TargetDetachedFromTarget(DetachedFromTargetEvent)
experimental and Target only.Issued when detached from target for any reason (including detachFromTarget command). Can be
issued multiple times per target if multiple sessions have been attached to it.
TargetReceivedMessageFromTarget(ReceivedMessageFromTargetEvent)
Target only.Notifies about a new protocol message received from the session (as reported in
attachedToTarget event).
TargetTargetCreated(TargetCreatedEvent)
Target only.Issued when a possible inspection target is created.
TargetTargetDestroyed(TargetDestroyedEvent)
Target only.Issued when a target is destroyed.
TargetTargetCrashed(TargetCrashedEvent)
Target only.Issued when a target has crashed.
TargetTargetInfoChanged(TargetInfoChangedEvent)
Target only.Issued when some information about a target has changed. This only happens between
targetCreated and targetDestroyed.
TetheringAccepted(AcceptedEvent)
experimental and Tethering only.Informs that port was successfully bound and got a specified connection id.
TracingBufferUsage(BufferUsageEvent)
experimental and IO and Tracing only.TracingDataCollected(DataCollectedEvent)
experimental and IO and Tracing only.Contains an bucket of collected trace events. When tracing is stopped collected events will be send as a sequence of dataCollected events followed by tracingComplete event.
TracingTracingComplete(TracingCompleteEvent)
experimental and IO and Tracing only.Signals that tracing is stopped and there is no trace buffers pending flush, all data were delivered via dataCollected events.
FetchRequestPaused(RequestPausedEvent)
Fetch and IO and Network and Page only.Issued when the domain is enabled and the request URL matches the specified filter. The request is paused until the client responds with one of continueRequest, failRequest or fulfillRequest. The stage of the request can be determined by presence of responseErrorReason and responseStatusCode – the request is at the response stage if either of these fields is present and in the request stage otherwise.
FetchAuthRequired(AuthRequiredEvent)
Fetch and IO and Network and Page only.Issued when the domain is enabled with handleAuthRequests set to true. The request is paused until client responds with continueWithAuth.
WebAudioContextCreated(ContextCreatedEvent)
experimental and WebAudio only.Notifies that a new BaseAudioContext has been created.
WebAudioContextWillBeDestroyed(ContextWillBeDestroyedEvent)
experimental and WebAudio only.Notifies that an existing BaseAudioContext will be destroyed.
WebAudioContextChanged(ContextChangedEvent)
experimental and WebAudio only.Notifies that existing BaseAudioContext has changed some properties (id stays the same)..
WebAudioAudioListenerCreated(AudioListenerCreatedEvent)
experimental and WebAudio only.Notifies that the construction of an AudioListener has finished.
WebAudioAudioListenerWillBeDestroyed(AudioListenerWillBeDestroyedEvent)
experimental and WebAudio only.Notifies that a new AudioListener has been created.
WebAudioAudioNodeCreated(AudioNodeCreatedEvent)
experimental and WebAudio only.Notifies that a new AudioNode has been created.
WebAudioAudioNodeWillBeDestroyed(AudioNodeWillBeDestroyedEvent)
experimental and WebAudio only.Notifies that an existing AudioNode has been destroyed.
WebAudioAudioParamCreated(AudioParamCreatedEvent)
experimental and WebAudio only.Notifies that a new AudioParam has been created.
WebAudioAudioParamWillBeDestroyed(AudioParamWillBeDestroyedEvent)
experimental and WebAudio only.Notifies that an existing AudioParam has been destroyed.
WebAudioNodesConnected(NodesConnectedEvent)
experimental and WebAudio only.Notifies that two AudioNodes are connected.
WebAudioNodesDisconnected(NodesDisconnectedEvent)
experimental and WebAudio only.Notifies that AudioNodes are disconnected. The destination can be null, and it means all the outgoing connections from the source are disconnected.
WebAudioNodeParamConnected(NodeParamConnectedEvent)
experimental and WebAudio only.Notifies that an AudioNode is connected to an AudioParam.
WebAudioNodeParamDisconnected(NodeParamDisconnectedEvent)
experimental and WebAudio only.Notifies that an AudioNode is disconnected to an AudioParam.
MediaPlayerPropertiesChanged(PlayerPropertiesChangedEvent)
experimental and Media only.This can be called multiple times, and can be used to set / override / remove player properties. A null propValue indicates removal.
MediaPlayerEventsAdded(PlayerEventsAddedEvent)
experimental and Media only.Send events as a list, allowing them to be batched on the browser for less congestion. If batched, events must ALWAYS be in chronological order.
MediaPlayerMessagesLogged(PlayerMessagesLoggedEvent)
experimental and Media only.Send a list of any messages that need to be delivered.
MediaPlayerErrorsRaised(PlayerErrorsRaisedEvent)
experimental and Media only.Send a list of any errors that need to be delivered.
MediaPlayersCreated(PlayersCreatedEvent)
experimental and Media only.Called whenever a player is created, or when a new agent joins and recieves a list of active players. If an agent is restored, it will recieve the full list of player ids and all events again.
ConsoleMessageAdded(MessageAddedEvent)
Console and Runtime only.Issued when new console message is added.
DebuggerBreakpointResolved(BreakpointResolvedEvent)
Debugger and Runtime only.Fired when breakpoint is resolved to an actual script and location.
DebuggerPaused(PausedEvent)
Debugger and Runtime only.Fired when the virtual machine stopped on breakpoint or exception or any other stop criteria.
DebuggerResumed(ResumedEvent)
Debugger and Runtime only.Fired when the virtual machine resumed execution.
DebuggerScriptFailedToParse(ScriptFailedToParseEvent)
Debugger and Runtime only.Fired when virtual machine fails to parse the script.
DebuggerScriptParsed(ScriptParsedEvent)
Debugger and Runtime only.Fired when virtual machine parses script. This event is also fired for all known and uncollected scripts upon enabling debugger.
HeapProfilerAddHeapSnapshotChunk(AddHeapSnapshotChunkEvent)
experimental and HeapProfiler and Runtime only.HeapProfilerHeapStatsUpdate(HeapStatsUpdateEvent)
experimental and HeapProfiler and Runtime only.If heap objects tracking has been started then backend may send update for one or more fragments
HeapProfilerLastSeenObjectId(LastSeenObjectIdEvent)
experimental and HeapProfiler and Runtime only.If heap objects tracking has been started then backend regularly sends a current value for last seen object id and corresponding timestamp. If the were changes in the heap since last event then one or more heapStatsUpdate events will be sent before a new lastSeenObjectId event.
HeapProfilerReportHeapSnapshotProgress(ReportHeapSnapshotProgressEvent)
experimental and HeapProfiler and Runtime only.HeapProfilerResetProfiles(ResetProfilesEvent)
experimental and HeapProfiler and Runtime only.ProfilerConsoleProfileFinished(ConsoleProfileFinishedEvent)
Debugger and Profiler and Runtime only.ProfilerConsoleProfileStarted(ConsoleProfileStartedEvent)
Debugger and Profiler and Runtime only.Sent when new profile recording is started using console.profile() call.
ProfilerPreciseCoverageDeltaUpdate(PreciseCoverageDeltaUpdateEvent)
Debugger and experimental and Profiler and Runtime only.Reports coverage delta since the last poll (either from an event like this, or from
takePreciseCoverage for the current isolate. May only be sent if precise code
coverage has been started. This event can be trigged by the embedder to, for example,
trigger collection of coverage data immediatelly at a certain point in time.
RuntimeBindingCalled(BindingCalledEvent)
experimental and Runtime only.Notification is issued every time when binding is called.
RuntimeConsoleApiCalled(ConsoleApiCalledEvent)
Runtime only.Issued when console API was called.
RuntimeExceptionRevoked(ExceptionRevokedEvent)
Runtime only.Issued when unhandled exception was revoked.
RuntimeExceptionThrown(ExceptionThrownEvent)
Runtime only.Issued when exception was thrown and unhandled.
RuntimeExecutionContextCreated(ExecutionContextCreatedEvent)
Runtime only.Issued when new execution context is created.
RuntimeExecutionContextDestroyed(ExecutionContextDestroyedEvent)
Runtime only.Issued when execution context is destroyed.
RuntimeExecutionContextsCleared(ExecutionContextsClearedEvent)
Runtime only.Issued when all executionContexts were cleared in browser
RuntimeInspectRequested(InspectRequestedEvent)
Runtime only.Issued when object should be inspected (for example, as a result of inspect() command line API call).
Unknown(String, Value)
Unknown event.