Struct chrome_remote_interface_model::headless_experimental::NeedsBeginFramesChangedEvent[][src]

pub struct NeedsBeginFramesChangedEvent { /* fields omitted */ }
👎 Deprecated
This is supported on crate features experimental and HeadlessExperimental and Page and Runtime only.

Issued when the target starts or stops needing BeginFrames. Deprecated. Issue beginFrame unconditionally instead and use result from beginFrame to detect whether the frames were suppressed.

Implementations

impl NeedsBeginFramesChangedEvent[src]

pub fn new(needs_begin_frames: bool) -> Self[src]

👎 Deprecated

pub fn needs_begin_frames(&self) -> bool[src]

👎 Deprecated

True if BeginFrames are needed, false otherwise.

Methods from Deref<Target = bool>