Module chrome_remote_interface_model::input[][src]

This is supported on crate feature Input only.

Structs

DispatchKeyEventCommand

Dispatches a key event to the page.

DispatchKeyEventCommandBuilder
DispatchKeyEventReturn

Dispatches a key event to the page.

DispatchMouseEventCommand

Dispatches a mouse event to the page.

DispatchMouseEventCommandBuilder
DispatchMouseEventReturn

Dispatches a mouse event to the page.

DispatchTouchEventCommand

Dispatches a touch event to the page.

DispatchTouchEventCommandBuilder
DispatchTouchEventReturn

Dispatches a touch event to the page.

EmulateTouchFromMouseEventCommandexperimental

Emulates touch event from the mouse event parameters.

EmulateTouchFromMouseEventCommandBuilderexperimental
EmulateTouchFromMouseEventReturnexperimental

Emulates touch event from the mouse event parameters.

InsertTextCommandexperimental

This method emulates inserting text that doesn't come from a key press, for example an emoji keyboard or an IME.

InsertTextReturnexperimental

This method emulates inserting text that doesn't come from a key press, for example an emoji keyboard or an IME.

SetIgnoreInputEventsCommand

Ignores input events (useful while auditing page).

SetIgnoreInputEventsReturn

Ignores input events (useful while auditing page).

SynthesizePinchGestureCommandexperimental

Synthesizes a pinch gesture over a time period by issuing appropriate touch events.

SynthesizePinchGestureCommandBuilderexperimental
SynthesizePinchGestureReturnexperimental

Synthesizes a pinch gesture over a time period by issuing appropriate touch events.

SynthesizeScrollGestureCommandexperimental

Synthesizes a scroll gesture over a time period by issuing appropriate touch events.

SynthesizeScrollGestureCommandBuilderexperimental
SynthesizeScrollGestureReturnexperimental

Synthesizes a scroll gesture over a time period by issuing appropriate touch events.

SynthesizeTapGestureCommandexperimental

Synthesizes a tap gesture over a time period by issuing appropriate touch events.

SynthesizeTapGestureCommandBuilderexperimental
SynthesizeTapGestureReturnexperimental

Synthesizes a tap gesture over a time period by issuing appropriate touch events.

TimeSinceEpoch

UTC time in seconds, counted from January 1, 1970.

TouchPoint
TouchPointBuilder

Enums

DispatchKeyEventCommandType
DispatchMouseEventCommandPointerType
DispatchMouseEventCommandType
DispatchTouchEventCommandType
EmulateTouchFromMouseEventCommandType
GestureSourceTypeexperimental
MouseButton