pub struct DispatchDragEventCommand { /* private fields */ }Available on crate features
Input and experimental only.Expand description
Dispatches a drag event into the page.
Implementations
Sourceimpl DispatchDragEventCommand
impl DispatchDragEventCommand
pub fn builder() -> DispatchDragEventCommandBuilder
Sourcepub fn type(&self) -> &DispatchDragEventCommandType
pub fn type(&self) -> &DispatchDragEventCommandType
Type of the drag event.
Sourcepub fn x(&self) -> f64
pub fn x(&self) -> f64
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y(&self) -> f64
pub fn y(&self) -> f64
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
pub fn data(&self) -> &JsonValue