pub struct DispatchDragEventCommandBuilder { /* private fields */ }Available on crate features
Input and experimental only.Implementations
Sourceimpl DispatchDragEventCommandBuilder
impl DispatchDragEventCommandBuilder
Sourcepub fn type(&mut self, v: DispatchDragEventCommandType) -> &mut Self
pub fn type(&mut self, v: DispatchDragEventCommandType) -> &mut Self
Type of the drag event.
Sourcepub fn x(&mut self, v: f64) -> &mut Self
pub fn x(&mut self, v: f64) -> &mut Self
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y(&mut self, v: f64) -> &mut Self
pub fn y(&mut self, v: f64) -> &mut Self
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
pub fn data(&mut self, v: JsonValue) -> &mut Self
Sourcepub fn modifiers(&mut self, v: u32) -> &mut Self
pub fn modifiers(&mut self, v: u32) -> &mut Self
Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
pub fn build(&mut self) -> Result<DispatchDragEventCommand, &'static str>