pub struct SynthesizePinchGestureCommand { /* private fields */ }Available on crate features
experimental and Input only.Expand description
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
Implementations
Sourceimpl SynthesizePinchGestureCommand
impl SynthesizePinchGestureCommand
pub fn builder() -> SynthesizePinchGestureCommandBuilder
Sourcepub fn scale_factor(&self) -> f64
pub fn scale_factor(&self) -> f64
Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
Sourcepub fn relative_speed(&self) -> Option<&u32>
pub fn relative_speed(&self) -> Option<&u32>
Relative pointer speed in pixels per second (default: 800).
Sourcepub fn gesture_source_type(&self) -> Option<&JsonValue>
pub fn gesture_source_type(&self) -> Option<&JsonValue>
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).