pub struct SynthesizePinchGestureCommandBuilder { /* private fields */ }Available on crate features
Input and experimental only.Implementations
Sourceimpl SynthesizePinchGestureCommandBuilder
impl SynthesizePinchGestureCommandBuilder
Sourcepub fn x(&mut self, v: f64) -> &mut Self
pub fn x(&mut self, v: f64) -> &mut Self
X coordinate of the start of the gesture in CSS pixels.
Sourcepub fn y(&mut self, v: f64) -> &mut Self
pub fn y(&mut self, v: f64) -> &mut Self
Y coordinate of the start of the gesture in CSS pixels.
Sourcepub fn scale_factor(&mut self, v: f64) -> &mut Self
pub fn scale_factor(&mut self, v: f64) -> &mut Self
Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
Sourcepub fn relative_speed(&mut self, v: u32) -> &mut Self
pub fn relative_speed(&mut self, v: u32) -> &mut Self
Relative pointer speed in pixels per second (default: 800).
Sourcepub fn gesture_source_type(&mut self, v: JsonValue) -> &mut Self
pub fn gesture_source_type(&mut self, v: JsonValue) -> &mut Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
pub fn build(&mut self) -> Result<SynthesizePinchGestureCommand, &'static str>