Struct chrome_remote_interface_model::input::SynthesizeTapGestureCommand [−][src]
This is supported on crate features
Input and experimental only.Synthesizes a tap gesture over a time period by issuing appropriate touch events.
Implementations
impl SynthesizeTapGestureCommand[src]
pub fn builder() -> SynthesizeTapGestureCommandBuilder[src]
pub fn x(&self) -> f64[src]
X coordinate of the start of the gesture in CSS pixels.
pub fn y(&self) -> f64[src]
Y coordinate of the start of the gesture in CSS pixels.
pub fn duration(&self) -> Option<&u32>[src]
Duration between touchdown and touchup events in ms (default: 50).
pub fn tap_count(&self) -> Option<&u32>[src]
Number of times to perform the tap (e.g. 2 for double tap, default: 1).
pub fn gesture_source_type(&self) -> Option<&JsonValue>[src]
Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type).