pub struct TouchPointBuilder { /* private fields */ }Input only.Implementations
Sourceimpl TouchPointBuilder
impl TouchPointBuilder
Sourcepub fn x(&mut self, v: f64) -> &mut Self
pub fn x(&mut self, v: f64) -> &mut Self
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y(&mut self, v: f64) -> &mut Self
pub fn y(&mut self, v: f64) -> &mut Self
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn rotation_angle(&mut self, v: f64) -> &mut Self
pub fn rotation_angle(&mut self, v: f64) -> &mut Self
Rotation angle (default: 0.0).
Sourcepub fn tangential_pressure(&mut self, v: f64) -> &mut Self
Available on crate feature experimental only.
pub fn tangential_pressure(&mut self, v: f64) -> &mut Self
experimental only.The normalized tangential pressure, which has a range of [-1,1] (default: 0).
Sourcepub fn tilt_x(&mut self, v: u32) -> &mut Self
Available on crate feature experimental only.
pub fn tilt_x(&mut self, v: u32) -> &mut Self
experimental only.The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0)
Sourcepub fn tilt_y(&mut self, v: u32) -> &mut Self
Available on crate feature experimental only.
pub fn tilt_y(&mut self, v: u32) -> &mut Self
experimental only.The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
Sourcepub fn twist(&mut self, v: u32) -> &mut Self
Available on crate feature experimental only.
pub fn twist(&mut self, v: u32) -> &mut Self
experimental only.The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
Sourcepub fn id(&mut self, v: f64) -> &mut Self
pub fn id(&mut self, v: f64) -> &mut Self
Identifier used to track touch sources between events, must be unique within an event.
pub fn build(&mut self) -> Result<TouchPoint, &'static str>