Available on crate features
Log and Runtime and Network only.Expand description
Provides access to log entries.
Structs
- Clear
Command - Clears the log.
- Clear
Return - Clears the log.
- Disable
Command - Disables log domain, prevents further log entries from being reported to the client.
- Disable
Return - Disables log domain, prevents further log entries from being reported to the client.
- Enable
Command - Enables log domain, sends the entries collected so far to the client by means of the
entryAddednotification. - Enable
Return - Enables log domain, sends the entries collected so far to the client by means of the
entryAddednotification. - Entry
Added Event - Issued when new message was logged.
- LogEntry
- Log entry.
- LogEntry
Builder - Start
Violations Report Command - start violation reporting.
- Start
Violations Report Return - start violation reporting.
- Stop
Violations Report Command - Stop violation reporting.
- Stop
Violations Report Return - Stop violation reporting.
- Violation
Setting - Violation configuration setting.