Module chrome_remote_interface_model::memory [−][src]
experimental and Memory only.Structs
| ForciblyPurgeJavaScriptMemoryCommand | Simulate OomIntervention by purging V8 memory. |
| ForciblyPurgeJavaScriptMemoryReturn | Simulate OomIntervention by purging V8 memory. |
| GetAllTimeSamplingProfileCommand | Retrieve native memory allocations profile collected since renderer process startup. |
| GetAllTimeSamplingProfileReturn | Retrieve native memory allocations profile collected since renderer process startup. |
| GetBrowserSamplingProfileCommand | Retrieve native memory allocations profile collected since browser process startup. |
| GetBrowserSamplingProfileReturn | Retrieve native memory allocations profile collected since browser process startup. |
| GetDomCountersCommand | |
| GetDomCountersReturn | |
| GetSamplingProfileCommand | Retrieve native memory allocations profile collected since last
|
| GetSamplingProfileReturn | Retrieve native memory allocations profile collected since last
|
| Module | Executable module information |
| ModuleBuilder | |
| PrepareForLeakDetectionCommand | |
| PrepareForLeakDetectionReturn | |
| SamplingProfile | Array of heap profile samples. |
| SamplingProfileNode | Heap profile sample. |
| SetPressureNotificationsSuppressedCommand | Enable/disable suppressing memory pressure notifications in all processes. |
| SetPressureNotificationsSuppressedReturn | Enable/disable suppressing memory pressure notifications in all processes. |
| SimulatePressureNotificationCommand | Simulate a memory pressure notification in all processes. |
| SimulatePressureNotificationReturn | Simulate a memory pressure notification in all processes. |
| StartSamplingCommand | Start collecting native memory profile. |
| StartSamplingReturn | Start collecting native memory profile. |
| StopSamplingCommand | Stop collecting native memory profile. |
| StopSamplingReturn | Stop collecting native memory profile. |
Enums
| PressureLevel |