Module chrome_remote_interface_model::network [−][src]
Network and Debugger and Runtime and Security only.Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.
Structs
| AuthChallenge | experimentalAuthorization challenge for HTTP status code 401 or 407. |
| AuthChallengeBuilder | experimental |
| AuthChallengeResponse | experimentalResponse to an AuthChallenge. |
| BlockedCookieWithReason | experimentalA cookie with was not sent with a request with the corresponding reason. |
| BlockedSetCookieWithReason | experimentalA cookie which was not stored from a response with the corresponding reason. |
| CachedResource | Information about the cached resource. |
| CachedResourceBuilder | |
| CanClearBrowserCacheCommand | Deprecated Tells whether clearing browser cache is supported. |
| CanClearBrowserCacheReturn | Deprecated Tells whether clearing browser cache is supported. |
| CanClearBrowserCookiesCommand | Deprecated Tells whether clearing browser cookies is supported. |
| CanClearBrowserCookiesReturn | Deprecated Tells whether clearing browser cookies is supported. |
| CanEmulateNetworkConditionsCommand | Deprecated Tells whether emulation of network conditions is supported. |
| CanEmulateNetworkConditionsReturn | Deprecated Tells whether emulation of network conditions is supported. |
| ClearBrowserCacheCommand | Clears browser cache. |
| ClearBrowserCacheReturn | Clears browser cache. |
| ClearBrowserCookiesCommand | Clears browser cookies. |
| ClearBrowserCookiesReturn | Clears browser cookies. |
| ContinueInterceptedRequestCommand | DeprecatedexperimentalResponse to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead. |
| ContinueInterceptedRequestCommandBuilder | Deprecatedexperimental |
| ContinueInterceptedRequestReturn | DeprecatedexperimentalResponse to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead. |
| Cookie | Cookie object |
| CookieBuilder | |
| CookieParam | Cookie parameter object |
| CookieParamBuilder | |
| CorsErrorStatus | |
| CrossOriginEmbedderPolicyStatus | experimental |
| CrossOriginEmbedderPolicyStatusBuilder | experimental |
| CrossOriginOpenerPolicyStatus | experimental |
| CrossOriginOpenerPolicyStatusBuilder | experimental |
| DataReceivedEvent | Fired when data chunk was received over the network. |
| DataReceivedEventBuilder | |
| DeleteCookiesCommand | Deletes browser cookies with matching name and url or domain/path pair. |
| DeleteCookiesCommandBuilder | |
| DeleteCookiesReturn | Deletes browser cookies with matching name and url or domain/path pair. |
| DisableCommand | Disables network tracking, prevents network events from being sent to the client. |
| DisableReturn | Disables network tracking, prevents network events from being sent to the client. |
| EmulateNetworkConditionsCommand | Activates emulation of network conditions. |
| EmulateNetworkConditionsCommandBuilder | |
| EmulateNetworkConditionsReturn | Activates emulation of network conditions. |
| EnableCommand | Enables network tracking, network events will now be delivered to the client. |
| EnableReturn | Enables network tracking, network events will now be delivered to the client. |
| EventSourceMessageReceivedEvent | Fired when EventSource message is received. |
| EventSourceMessageReceivedEventBuilder | |
| GetAllCookiesCommand | Returns all browser cookies. Depending on the backend support, will return detailed cookie
information in the |
| GetAllCookiesReturn | Returns all browser cookies. Depending on the backend support, will return detailed cookie
information in the |
| GetCertificateCommand | experimentalReturns the DER-encoded certificate. |
| GetCertificateReturn | experimentalReturns the DER-encoded certificate. |
| GetCookiesCommand | Returns all browser cookies for the current URL. Depending on the backend support, will return
detailed cookie information in the |
| GetCookiesReturn | Returns all browser cookies for the current URL. Depending on the backend support, will return
detailed cookie information in the |
| GetRequestPostDataCommand | Returns post data sent with the request. Returns an error when no data was sent with the request. |
| GetRequestPostDataReturn | Returns post data sent with the request. Returns an error when no data was sent with the request. |
| GetResponseBodyCommand | Returns content served for the given request. |
| GetResponseBodyForInterceptionCommand | experimentalReturns content served for the given currently intercepted request. |
| GetResponseBodyForInterceptionReturn | experimentalReturns content served for the given currently intercepted request. |
| GetResponseBodyReturn | Returns content served for the given request. |
| GetSecurityIsolationStatusCommand | experimentalReturns information about the COEP/COOP isolation status. |
| GetSecurityIsolationStatusReturn | experimentalReturns information about the COEP/COOP isolation status. |
| Headers | Request / response headers as keys / values of JSON object. |
| Initiator | Information about the request initiator. |
| InitiatorBuilder | |
| InterceptionId | Unique intercepted request identifier. |
| LoadNetworkResourceCommand | experimentalFetches the resource and returns the content. |
| LoadNetworkResourceOptions | experimentalAn options object that may be extended later to better support CORS, CORB and streaming. |
| LoadNetworkResourcePageResult | experimentalAn object providing the result of a network resource load. |
| LoadNetworkResourcePageResultBuilder | experimental |
| LoadNetworkResourceReturn | experimentalFetches the resource and returns the content. |
| LoaderId | Unique loader identifier. |
| LoadingFailedEvent | Fired when HTTP request has failed to load. |
| LoadingFailedEventBuilder | |
| LoadingFinishedEvent | Fired when HTTP request has finished loading. |
| LoadingFinishedEventBuilder | |
| MonotonicTime | Monotonically increasing time in seconds since an arbitrary point in the past. |
| PostDataEntry | Post data entry for HTTP request |
| ReplayXhrCommand | experimentalThis method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password. |
| ReplayXhrReturn | experimentalThis method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password. |
| Request | HTTP request data. |
| RequestBuilder | |
| RequestId | Unique request identifier. |
| RequestInterceptedEvent | DeprecatedexperimentalDetails of an intercepted HTTP request, which must be either allowed, blocked, modified or mocked. Deprecated, use Fetch.requestPaused instead. |
| RequestInterceptedEventBuilder | Deprecatedexperimental |
| RequestPattern | experimentalRequest pattern for interception. |
| RequestServedFromCacheEvent | Fired if request ended up loading from cache. |
| RequestWillBeSentEvent | Fired when page is about to send HTTP request. |
| RequestWillBeSentEventBuilder | |
| RequestWillBeSentExtraInfoEvent | experimentalFired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request. |
| ResourceChangedPriorityEvent | experimentalFired when resource loading priority is changed |
| ResourceTiming | Timing information for the request. |
| ResourceTimingBuilder | |
| Response | HTTP response data. |
| ResponseBuilder | |
| ResponseReceivedEvent | Fired when HTTP response is available. |
| ResponseReceivedEventBuilder | |
| ResponseReceivedExtraInfoEvent | experimentalFired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived. |
| ResponseReceivedExtraInfoEventBuilder | experimental |
| SearchInResponseBodyCommand | experimentalSearches for given string in response content. |
| SearchInResponseBodyCommandBuilder | experimental |
| SearchInResponseBodyReturn | experimentalSearches for given string in response content. |
| SecurityDetails | Security details about a request. |
| SecurityDetailsBuilder | |
| SecurityIsolationStatus | experimental |
| SetAttachDebugStackCommand | experimentalSpecifies whether to attach a page script stack id in requests |
| SetAttachDebugStackReturn | experimentalSpecifies whether to attach a page script stack id in requests |
| SetBlockedUrLsCommand | experimentalBlocks URLs from loading. |
| SetBlockedUrLsReturn | experimentalBlocks URLs from loading. |
| SetBypassServiceWorkerCommand | experimentalToggles ignoring of service worker for each request. |
| SetBypassServiceWorkerReturn | experimentalToggles ignoring of service worker for each request. |
| SetCacheDisabledCommand | Toggles ignoring cache for each request. If |
| SetCacheDisabledReturn | Toggles ignoring cache for each request. If |
| SetCookieCommand | Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist. |
| SetCookieCommandBuilder | |
| SetCookieReturn | Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist. |
| SetCookiesCommand | Sets given cookies. |
| SetCookiesReturn | Sets given cookies. |
| SetDataSizeLimitsForTestCommand | experimentalFor testing. |
| SetDataSizeLimitsForTestReturn | experimentalFor testing. |
| SetExtraHttpHeadersCommand | Specifies whether to always send extra HTTP headers with the requests from this page. |
| SetExtraHttpHeadersReturn | Specifies whether to always send extra HTTP headers with the requests from this page. |
| SetRequestInterceptionCommand | DeprecatedexperimentalSets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead. |
| SetRequestInterceptionReturn | DeprecatedexperimentalSets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead. |
| SetUserAgentOverrideCommand | Allows overriding user agent with the given string. |
| SetUserAgentOverrideCommandBuilder | |
| SetUserAgentOverrideReturn | Allows overriding user agent with the given string. |
| SignedCertificateTimestamp | Details of a signed certificate timestamp (SCT). |
| SignedCertificateTimestampBuilder | |
| SignedExchangeError | experimentalInformation about a signed exchange response. |
| SignedExchangeHeader | experimentalInformation about a signed exchange header. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#cbor-representation |
| SignedExchangeHeaderBuilder | experimental |
| SignedExchangeInfo | experimentalInformation about a signed exchange response. |
| SignedExchangeInfoBuilder | experimental |
| SignedExchangeReceivedEvent | experimentalFired when a signed exchange was received over the network |
| SignedExchangeSignature | experimentalInformation about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1 |
| SignedExchangeSignatureBuilder | experimental |
| TakeResponseBodyForInterceptionAsStreamCommand | experimentalReturns a handle to the stream representing the response body. Note that after this command, the intercepted request can't be continued as is -- you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. |
| TakeResponseBodyForInterceptionAsStreamReturn | experimentalReturns a handle to the stream representing the response body. Note that after this command, the intercepted request can't be continued as is -- you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. |
| TimeSinceEpoch | UTC time in seconds, counted from January 1, 1970. |
| TrustTokenParams | experimentalDetermines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl. |
| WebSocketClosedEvent | Fired when WebSocket is closed. |
| WebSocketCreatedEvent | Fired upon WebSocket creation. |
| WebSocketFrame | WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests. |
| WebSocketFrameErrorEvent | Fired when WebSocket message error occurs. |
| WebSocketFrameReceivedEvent | Fired when WebSocket message is received. |
| WebSocketFrameSentEvent | Fired when WebSocket message is sent. |
| WebSocketHandshakeResponseReceivedEvent | Fired when WebSocket handshake response becomes available. |
| WebSocketRequest | WebSocket request data. |
| WebSocketResponse | WebSocket response data. |
| WebSocketResponseBuilder | |
| WebSocketWillSendHandshakeRequestEvent | Fired when WebSocket is about to initiate handshake. |
| WebSocketWillSendHandshakeRequestEventBuilder |