Response

Struct Response 

pub struct Response { /* private fields */ }
Available on crate features Network and Debugger and Runtime and Security only.
HTTP response data.

Implementations

Source

impl Response

pub fn builder() -> ResponseBuilder

pub fn url(&self) -> &str

Response URL. This URL can be different from CachedResource.url in case of redirect.

pub fn status(&self) -> u32

HTTP response status code.

pub fn status_text(&self) -> &str

HTTP response status text.

pub fn headers(&self) -> &Headers

HTTP response headers.

pub fn headers_text(&self) -> Option<&String>

HTTP response headers text.

pub fn mime_type(&self) -> &str

Resource mimeType as determined by the browser.

pub fn request_headers(&self) -> Option<&Headers>

Refined HTTP request headers that were actually transmitted over the network.

pub fn request_headers_text(&self) -> Option<&String>

HTTP request headers text.

pub fn connection_reused(&self) -> bool

Specifies whether physical connection was actually reused for this request.

pub fn connection_id(&self) -> f64

Physical connection id that was actually used for this request.

pub fn remote_ip_address(&self) -> Option<&String>

Remote IP address.

pub fn remote_port(&self) -> Option<&u32>

Remote port.

pub fn from_disk_cache(&self) -> Option<&bool>

Specifies that the request was served from the disk cache.

pub fn from_service_worker(&self) -> Option<&bool>

Specifies that the request was served from the ServiceWorker.

pub fn from_prefetch_cache(&self) -> Option<&bool>

Specifies that the request was served from the prefetch cache.

pub fn encoded_data_length(&self) -> f64

Total number of bytes received for this request so far.

pub fn timing(&self) -> Option<&ResourceTiming>

Timing information for the given request.

pub fn service_worker_response_source( &self, ) -> Option<&ServiceWorkerResponseSource>

Response source of response from ServiceWorker.

pub fn response_time(&self) -> Option<&TimeSinceEpoch>

The time at which the returned response was generated.

pub fn cache_storage_cache_name(&self) -> Option<&String>

Cache Storage Cache Name.

pub fn protocol(&self) -> Option<&String>

Protocol used to fetch this request.

pub fn security_state(&self) -> &SecurityState

Security state of the request resource.

pub fn security_details(&self) -> Option<&SecurityDetails>

Security details for the request.