pub struct SetCookieCommandBuilder { /* private fields */ }Available on crate features
Network and Debugger and Runtime and Security only.Implementations
Sourceimpl SetCookieCommandBuilder
impl SetCookieCommandBuilder
Sourcepub fn url(&mut self, v: String) -> &mut Self
pub fn url(&mut self, v: String) -> &mut Self
The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.
Sourcepub fn same_site(&mut self, v: CookieSameSite) -> &mut Self
pub fn same_site(&mut self, v: CookieSameSite) -> &mut Self
Cookie SameSite type.
Sourcepub fn expires(&mut self, v: TimeSinceEpoch) -> &mut Self
pub fn expires(&mut self, v: TimeSinceEpoch) -> &mut Self
Cookie expiration date, session cookie if not set
Sourcepub fn priority(&mut self, v: JsonValue) -> &mut Self
Available on crate feature experimental only.
pub fn priority(&mut self, v: JsonValue) -> &mut Self
experimental only.Cookie Priority type.
Sourcepub fn same_party(&mut self, v: bool) -> &mut Self
Available on crate feature experimental only.
pub fn same_party(&mut self, v: bool) -> &mut Self
experimental only.True if cookie is SameParty.
Sourcepub fn source_scheme(&mut self, v: JsonValue) -> &mut Self
Available on crate feature experimental only.
pub fn source_scheme(&mut self, v: JsonValue) -> &mut Self
experimental only.Cookie source scheme type.
Sourcepub fn source_port(&mut self, v: u32) -> &mut Self
Available on crate feature experimental only.
pub fn source_port(&mut self, v: u32) -> &mut Self
experimental only.Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.
pub fn build(&mut self) -> Result<SetCookieCommand, &'static str>