Struct chrome_remote_interface_model::network::SignedExchangeSignature [−][src]
This is supported on crate features
Network and Debugger and Runtime and Security and experimental only.Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
Implementations
impl SignedExchangeSignature[src]
pub fn builder() -> SignedExchangeSignatureBuilder[src]
pub fn label(&self) -> &str[src]
Signed exchange signature label.
pub fn signature(&self) -> &str[src]
The hex string of signed exchange signature.
pub fn integrity(&self) -> &str[src]
Signed exchange signature integrity.
pub fn cert_url(&self) -> Option<&String>[src]
Signed exchange signature cert Url.
pub fn cert_sha256(&self) -> Option<&String>[src]
The hex string of signed exchange signature cert sha256.
pub fn validity_url(&self) -> &str[src]
Signed exchange signature validity Url.
pub fn date(&self) -> u32[src]
Signed exchange signature date.
pub fn expires(&self) -> u32[src]
Signed exchange signature expires.
pub fn certificates(&self) -> Option<&Vec<String>>[src]
The encoded certificates.