pub struct FlexItemHighlightConfig { /* private fields */ }Available on crate features
experimental and Overlay and DOM and Page and Runtime only.Expand description
Configuration data for the highlighting of Flex item elements.
Implementations
Sourceimpl FlexItemHighlightConfig
impl FlexItemHighlightConfig
pub fn new( base_size_box: Option<BoxStyle>, base_size_border: Option<LineStyle>, flexibility_arrow: Option<LineStyle>, ) -> Self
Sourcepub fn base_size_box(&self) -> Option<&BoxStyle>
pub fn base_size_box(&self) -> Option<&BoxStyle>
Style of the box representing the item’s base size
Sourcepub fn base_size_border(&self) -> Option<&LineStyle>
pub fn base_size_border(&self) -> Option<&LineStyle>
Style of the border around the box representing the item’s base size
Sourcepub fn flexibility_arrow(&self) -> Option<&LineStyle>
pub fn flexibility_arrow(&self) -> Option<&LineStyle>
Style of the arrow representing if the item grew or shrank