DeleteCookieCommand

Struct DeleteCookieCommand 

pub struct DeleteCookieCommand { /* private fields */ }
👎Deprecated
Available on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.
Deletes browser cookie with given name, domain and path.

Implementations

Source

impl DeleteCookieCommand

pub fn new(cookie_name: String, url: String) -> Self

👎Deprecated
pub fn cookie_name(&self) -> &str

👎Deprecated

Name of the cookie to remove.

pub fn url(&self) -> &str

👎Deprecated

URL to match cooke domain and path.