pub struct DownloadWillBeginEventBuilder { /* private fields */ }๐Deprecated
Available on crate features
Page and Debugger and DOM and IO and Network and Runtime and experimental only.Implementations
Sourceimpl DownloadWillBeginEventBuilder
impl DownloadWillBeginEventBuilder
Sourcepub fn frame_id(&mut self, v: FrameId) -> &mut Self
๐Deprecated
pub fn frame_id(&mut self, v: FrameId) -> &mut Self
Id of the frame that caused download to begin.
Sourcepub fn guid(&mut self, v: String) -> &mut Self
๐Deprecated
pub fn guid(&mut self, v: String) -> &mut Self
Global unique identifier of the download.
Sourcepub fn url(&mut self, v: String) -> &mut Self
๐Deprecated
pub fn url(&mut self, v: String) -> &mut Self
URL of the resource being downloaded.
Sourcepub fn suggested_filename(&mut self, v: String) -> &mut Self
๐Deprecated
pub fn suggested_filename(&mut self, v: String) -> &mut Self
Suggested file name of the resource (the actual name of the file saved on disk may differ).
pub fn build(&mut self) -> Result<DownloadWillBeginEvent, &'static str>
๐Deprecated