PrintToPdfCommandBuilder

Struct PrintToPdfCommandBuilder 

pub struct PrintToPdfCommandBuilder { /* private fields */ }
Available on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Implementations

Source

impl PrintToPdfCommandBuilder

pub fn landscape(&mut self, v: bool) -> &mut Self

Paper orientation. Defaults to false.

Display header and footer. Defaults to false.

pub fn print_background(&mut self, v: bool) -> &mut Self

Print background graphics. Defaults to false.

pub fn scale(&mut self, v: f64) -> &mut Self

Scale of the webpage rendering. Defaults to 1.

pub fn paper_width(&mut self, v: f64) -> &mut Self

Paper width in inches. Defaults to 8.5 inches.

pub fn paper_height(&mut self, v: f64) -> &mut Self

Paper height in inches. Defaults to 11 inches.

pub fn margin_top(&mut self, v: f64) -> &mut Self

Top margin in inches. Defaults to 1cm (~0.4 inches).

pub fn margin_bottom(&mut self, v: f64) -> &mut Self

Bottom margin in inches. Defaults to 1cm (~0.4 inches).

pub fn margin_left(&mut self, v: f64) -> &mut Self

Left margin in inches. Defaults to 1cm (~0.4 inches).

pub fn margin_right(&mut self, v: f64) -> &mut Self

Right margin in inches. Defaults to 1cm (~0.4 inches).

pub fn page_ranges(&mut self, v: String) -> &mut Self

Paper ranges to print, e.g., ‘1-5, 8, 11-13’. Defaults to the empty string, which means print all pages.

pub fn ignore_invalid_page_ranges(&mut self, v: bool) -> &mut Self

Whether to silently ignore invalid but successfully parsed page ranges, such as ‘3-2’. Defaults to false.

pub fn header_template(&mut self, v: String) -> &mut Self

HTML template for the print header. Should be valid HTML markup with following classes used to inject printing values into them:

  • date: formatted print date
  • title: document title
  • url: document location
  • pageNumber: current page number
  • totalPages: total pages in the document

For example, <span class=title></span> would generate span containing the title.

pub fn footer_template(&mut self, v: String) -> &mut Self

HTML template for the print footer. Should use the same format as the headerTemplate.

pub fn prefer_css_page_size(&mut self, v: bool) -> &mut Self

Whether or not to prefer page size as defined by css. Defaults to false, in which case the content will be scaled to fit the paper size.

pub fn transfer_mode(&mut self, v: PrintToPdfCommandTransferMode) -> &mut Self

Available on crate feature experimental only.

return as stream

pub fn build(&mut self) -> Result<PrintToPdfCommand, &'static str>