Struct chrome_remote_interface_model::page::SetInterceptFileChooserDialogReturn [−][src]
This is supported on crate features
Page and Debugger and DOM and IO and Network and Runtime and experimental only.Intercept file chooser requests and transfer control to protocol clients.
When file chooser interception is enabled, native file chooser dialog is not shown.
Instead, a protocol event Page.fileChooserOpened is emitted.
Implementations
impl SetInterceptFileChooserDialogReturn[src]