Module chrome_remote_interface_model::performance [−][src]
This is supported on crate feature
Performance only.Structs
| DisableCommand | Disable collecting and reporting metrics. |
| DisableReturn | Disable collecting and reporting metrics. |
| EnableCommand | Enable collecting and reporting metrics. |
| EnableReturn | Enable collecting and reporting metrics. |
| GetMetricsCommand | Retrieve current values of run-time metrics. |
| GetMetricsReturn | Retrieve current values of run-time metrics. |
| Metric | Run-time execution metric. |
| MetricsEvent | Current values of the metrics. |
| SetTimeDomainCommand | DeprecatedexperimentalSets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error. |
| SetTimeDomainReturn | DeprecatedexperimentalSets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error. |
Enums
| EnableCommandTimeDomain | |
| SetTimeDomainCommandTimeDomain |