Module profiler

Module profiler 

Available on crate features Profiler and Runtime and Debugger only.

Structs

ConsoleProfileFinishedEvent
ConsoleProfileFinishedEventBuilder
ConsoleProfileStartedEvent
Sent when new profile recording is started using console.profile() call.
CounterInfoexperimental
Collected counter information.
CoverageRange
Coverage data for a source range.
DisableCommand
DisableCountersCommandexperimental
Disable counters collection.
DisableCountersReturnexperimental
Disable counters collection.
DisableReturn
DisableRuntimeCallStatsCommandexperimental
Disable run time call stats collection.
DisableRuntimeCallStatsReturnexperimental
Disable run time call stats collection.
EnableCommand
EnableCountersCommandexperimental
Enable counters collection.
EnableCountersReturnexperimental
Enable counters collection.
EnableReturn
EnableRuntimeCallStatsCommandexperimental
Enable run time call stats collection.
EnableRuntimeCallStatsReturnexperimental
Enable run time call stats collection.
FunctionCoverage
Coverage data for a JavaScript function.
GetBestEffortCoverageCommand
Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
GetBestEffortCoverageReturn
Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
GetCountersCommandexperimental
Retrieve counters.
GetCountersReturnexperimental
Retrieve counters.
GetRuntimeCallStatsCommandexperimental
Retrieve run time call stats.
GetRuntimeCallStatsReturnexperimental
Retrieve run time call stats.
PositionTickInfo
Specifies a number of samples attributed to a certain source position.
PreciseCoverageDeltaUpdateEventexperimental
Reports coverage delta since the last poll (either from an event like this, or from takePreciseCoverage for the current isolate. May only be sent if precise code coverage has been started. This event can be trigged by the embedder to, for example, trigger collection of coverage data immediatelly at a certain point in time.
Profile
Profile.
ProfileBuilder
ProfileNode
Profile node. Holds callsite information, execution statistics and child nodes.
ProfileNodeBuilder
RuntimeCallCounterInfoexperimental
Runtime call counter information.
ScriptCoverage
Coverage data for a JavaScript script.
ScriptTypeProfileexperimental
Type profile data collected during runtime for a JavaScript script.
SetSamplingIntervalCommand
Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.
SetSamplingIntervalReturn
Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.
StartCommand
StartPreciseCoverageCommand
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
StartPreciseCoverageReturn
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
StartReturn
StartTypeProfileCommandexperimental
Enable type profile.
StartTypeProfileReturnexperimental
Enable type profile.
StopCommand
StopPreciseCoverageCommand
Disable precise code coverage. Disabling releases unnecessary execution count records and allows executing optimized code.
StopPreciseCoverageReturn
Disable precise code coverage. Disabling releases unnecessary execution count records and allows executing optimized code.
StopReturn
StopTypeProfileCommandexperimental
Disable type profile. Disabling releases type profile data collected so far.
StopTypeProfileReturnexperimental
Disable type profile. Disabling releases type profile data collected so far.
TakePreciseCoverageCommand
Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.
TakePreciseCoverageReturn
Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.
TakeTypeProfileCommandexperimental
Collect type profile.
TakeTypeProfileReturnexperimental
Collect type profile.
TypeObjectexperimental
Describes a type collected during runtime.
TypeProfileEntryexperimental
Source offset and types for a parameter or return value.