Struct chrome_remote_interface_model::profiler::PositionTickInfo[][src]

pub struct PositionTickInfo { /* fields omitted */ }
This is supported on crate features Profiler and Runtime and Debugger only.

Specifies a number of samples attributed to a certain source position.

Implementations

impl PositionTickInfo[src]

pub fn new(line: u32, ticks: u32) -> Self[src]

pub fn line(&self) -> u32[src]

Source line number (1-based).

pub fn ticks(&self) -> u32[src]

Number of samples attributed to the source line.