TakePreciseCoverageReturn

Struct TakePreciseCoverageReturn 

pub struct TakePreciseCoverageReturn { /* private fields */ }
Available on crate features Profiler and Runtime and Debugger only.
Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.

Implementations

Source

impl TakePreciseCoverageReturn

pub fn new(result: Vec<ScriptCoverage>, timestamp: f64) -> Self

pub fn result(&self) -> &[ScriptCoverage]

Coverage data for the current isolate.

pub fn timestamp(&self) -> f64

Monotonically increasing time (in seconds) when the coverage update was taken in the backend.