Module chrome_remote_interface_model::runtime [−][src]
Runtime only.Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group.
Structs
| AddBindingCommand | experimentalIf executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification. |
| AddBindingReturn | experimentalIf executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification. |
| AwaitPromiseCommand | Add handler to promise with given promise object id. |
| AwaitPromiseReturn | Add handler to promise with given promise object id. |
| BindingCalledEvent | experimentalNotification is issued every time when binding is called. |
| CallArgument | Represents function call argument. Either remote object id |
| CallFrame | Stack entry for runtime errors and assertions. |
| CallFrameBuilder | |
| CallFunctionOnCommand | Calls function with given declaration on the given object. Object group of the result is inherited from the target object. |
| CallFunctionOnCommandBuilder | |
| CallFunctionOnReturn | Calls function with given declaration on the given object. Object group of the result is inherited from the target object. |
| CompileScriptCommand | Compiles expression. |
| CompileScriptCommandBuilder | |
| CompileScriptReturn | Compiles expression. |
| ConsoleApiCalledEvent | Issued when console API was called. |
| ConsoleApiCalledEventBuilder | |
| CustomPreview | experimental |
| DisableCommand | Disables reporting of execution contexts creation. |
| DisableReturn | Disables reporting of execution contexts creation. |
| DiscardConsoleEntriesCommand | Discards collected exceptions and console API calls. |
| DiscardConsoleEntriesReturn | Discards collected exceptions and console API calls. |
| EnableCommand | Enables reporting of execution contexts creation by means of |
| EnableReturn | Enables reporting of execution contexts creation by means of |
| EntryPreview | experimental |
| EvaluateCommand | Evaluates expression on global object. |
| EvaluateCommandBuilder | |
| EvaluateReturn | Evaluates expression on global object. |
| ExceptionDetails | Detailed information about exception (or error) that was thrown during script compilation or execution. |
| ExceptionDetailsBuilder | |
| ExceptionRevokedEvent | Issued when unhandled exception was revoked. |
| ExceptionThrownEvent | Issued when exception was thrown and unhandled. |
| ExecutionContextCreatedEvent | Issued when new execution context is created. |
| ExecutionContextDescription | Description of an isolated world. |
| ExecutionContextDescriptionAuxData | |
| ExecutionContextDescriptionBuilder | |
| ExecutionContextDestroyedEvent | Issued when execution context is destroyed. |
| ExecutionContextId | Id of an execution context. |
| ExecutionContextsClearedEvent | Issued when all executionContexts were cleared in browser |
| GetHeapUsageCommand | experimentalReturns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime. |
| GetHeapUsageReturn | experimentalReturns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime. |
| GetIsolateIdCommand | experimentalReturns the isolate id. |
| GetIsolateIdReturn | experimentalReturns the isolate id. |
| GetPropertiesCommand | Returns properties of a given object. Object group of the result is inherited from the target object. |
| GetPropertiesCommandBuilder | |
| GetPropertiesReturn | Returns properties of a given object. Object group of the result is inherited from the target object. |
| GetPropertiesReturnBuilder | |
| GlobalLexicalScopeNamesCommand | Returns all let, const and class variables from global scope. |
| GlobalLexicalScopeNamesReturn | Returns all let, const and class variables from global scope. |
| InspectRequestedEvent | Issued when object should be inspected (for example, as a result of inspect() command line API call). |
| InspectRequestedEventHints | |
| InternalPropertyDescriptor | Object internal property descriptor. This property isn't normally visible in JavaScript code. |
| ObjectPreview | experimentalObject containing abbreviated remote object value. |
| ObjectPreviewBuilder | experimental |
| PrivatePropertyDescriptor | experimentalObject private field descriptor. |
| PrivatePropertyDescriptorBuilder | experimental |
| PropertyDescriptor | Object property descriptor. |
| PropertyDescriptorBuilder | |
| PropertyPreview | experimental |
| PropertyPreviewBuilder | experimental |
| QueryObjectsCommand | |
| QueryObjectsReturn | |
| ReleaseObjectCommand | Releases remote object with given id. |
| ReleaseObjectGroupCommand | Releases all remote objects that belong to a given group. |
| ReleaseObjectGroupReturn | Releases all remote objects that belong to a given group. |
| ReleaseObjectReturn | Releases remote object with given id. |
| RemoteObject | Mirror object referencing original JavaScript object. |
| RemoteObjectBuilder | |
| RemoteObjectId | Unique object identifier. |
| RemoveBindingCommand | experimentalThis method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications. |
| RemoveBindingReturn | experimentalThis method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications. |
| RunIfWaitingForDebuggerCommand | Tells inspected instance to run if it was waiting for debugger to attach. |
| RunIfWaitingForDebuggerReturn | Tells inspected instance to run if it was waiting for debugger to attach. |
| RunScriptCommand | Runs script with given id in a given context. |
| RunScriptCommandBuilder | |
| RunScriptReturn | Runs script with given id in a given context. |
| ScriptId | Unique script identifier. |
| SetAsyncCallStackDepthCommand | Enables or disables async call stacks tracking. |
| SetAsyncCallStackDepthReturn | Enables or disables async call stacks tracking. |
| SetCustomObjectFormatterEnabledCommand | experimental |
| SetCustomObjectFormatterEnabledReturn | experimental |
| SetMaxCallStackSizeToCaptureCommand | experimental |
| SetMaxCallStackSizeToCaptureReturn | experimental |
| StackTrace | Call frames for assertions or error messages. |
| StackTraceBuilder | |
| StackTraceId | experimentalIf |
| TerminateExecutionCommand | experimentalTerminate current or next JavaScript execution. Will cancel the termination when the outer-most script execution ends. |
| TerminateExecutionReturn | experimentalTerminate current or next JavaScript execution. Will cancel the termination when the outer-most script execution ends. |
| TimeDelta | Number of milliseconds. |
| Timestamp | Number of milliseconds since epoch. |
| UniqueDebuggerId | experimentalUnique identifier of current debugger. |
| UnserializableValue | Primitive value which cannot be JSON-stringified. Includes values |
Enums
| ConsoleApiCalledEventType | |
| ObjectPreviewSubtype | |
| ObjectPreviewType | |
| PropertyPreviewSubtype | |
| PropertyPreviewType | |
| RemoteObjectSubtype | |
| RemoteObjectType |