CompileScriptCommand

Struct CompileScriptCommand 

pub struct CompileScriptCommand { /* private fields */ }
Available on crate feature Runtime only.
Compiles expression.

Implementations

Source

impl CompileScriptCommand

pub fn builder() -> CompileScriptCommandBuilder

pub fn expression(&self) -> &str

Expression to compile.

pub fn source_url(&self) -> &str

Source url to be set for the script.

pub fn persist_script(&self) -> bool

Specifies whether the compiled script should be persisted.

pub fn execution_context_id(&self) -> Option<&ExecutionContextId>

Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.