Struct chrome_remote_interface_model::runtime::EnableCommand[][src]

pub struct EnableCommand {}
This is supported on crate feature Runtime only.

Enables reporting of execution contexts creation by means of executionContextCreated event. When the reporting gets enabled the event will be sent immediately for each existing execution context.

Implementations

impl EnableCommand[src]

pub fn new() -> Self[src]