pub struct ExceptionDetails { /* private fields */ }Available on crate feature
Runtime only.Expand description
Detailed information about exception (or error) that was thrown during script compilation or execution.
Implementations
Sourceimpl ExceptionDetails
impl ExceptionDetails
pub fn builder() -> ExceptionDetailsBuilder
Sourcepub fn exception_id(&self) -> u32
pub fn exception_id(&self) -> u32
Exception id.
Sourcepub fn text(&self) -> &str
pub fn text(&self) -> &str
Exception text, which should be used together with exception object when available.
Sourcepub fn line_number(&self) -> u32
pub fn line_number(&self) -> u32
Line number of the exception location (0-based).
Sourcepub fn column_number(&self) -> u32
pub fn column_number(&self) -> u32
Column number of the exception location (0-based).
Sourcepub fn url(&self) -> Option<&String>
pub fn url(&self) -> Option<&String>
URL of the exception location, to be used when the script was not reported.
Sourcepub fn stack_trace(&self) -> Option<&StackTrace>
pub fn stack_trace(&self) -> Option<&StackTrace>
JavaScript stack trace if available.
Sourcepub fn exception(&self) -> Option<&RemoteObject>
pub fn exception(&self) -> Option<&RemoteObject>
Exception object if available.
Sourcepub fn execution_context_id(&self) -> Option<&ExecutionContextId>
pub fn execution_context_id(&self) -> Option<&ExecutionContextId>
Identifier of the context where exception happened.