Module security

Module security 

Available on crate feature Security only.
Security

Structs

CertificateErrorEventDeprecated
There is a certificate error. If overriding certificate errors is enabled, then it should be handled with the handleCertificateError command. Note: this event does not fire if the certificate error has been allowed internally. Only one client per target should override certificate errors at the same time.
CertificateId
An internal certificate ID value.
CertificateSecurityStateexperimental
Details about the security state of the page certificate.
CertificateSecurityStateBuilderexperimental
DisableCommand
Disables tracking security state changes.
DisableReturn
Disables tracking security state changes.
EnableCommand
Enables tracking security state changes.
EnableReturn
Enables tracking security state changes.
HandleCertificateErrorCommandDeprecated
Handles a certificate error that fired a certificateError event.
HandleCertificateErrorReturnDeprecated
Handles a certificate error that fired a certificateError event.
InsecureContentStatusDeprecated
Information about insecure content on the page.
InsecureContentStatusBuilderDeprecated
SafetyTipInfoexperimental
SecurityStateChangedEvent
The security state of the page changed.
SecurityStateChangedEventBuilder
SecurityStateExplanation
An explanation of an factor contributing to the security state.
SecurityStateExplanationBuilder
SetIgnoreCertificateErrorsCommandexperimental
Enable/disable whether all certificate errors should be ignored.
SetIgnoreCertificateErrorsReturnexperimental
Enable/disable whether all certificate errors should be ignored.
SetOverrideCertificateErrorsCommandDeprecated
Enable/disable overriding certificate errors. If enabled, all certificate error events need to be handled by the DevTools client and should be answered with handleCertificateError commands.
SetOverrideCertificateErrorsReturnDeprecated
Enable/disable overriding certificate errors. If enabled, all certificate error events need to be handled by the DevTools client and should be answered with handleCertificateError commands.
VisibleSecurityStateexperimental
Security state information about the page.
VisibleSecurityStateBuilderexperimental
VisibleSecurityStateChangedEventexperimental
The security state of the page changed.

Enums

CertificateErrorAction
MixedContentType
SafetyTipStatusexperimental
SecurityState