Module chrome_remote_interface_model::tethering [−][src]
This is supported on crate features
experimental and Tethering only.The Tethering domain defines methods and events for browser port binding.
Structs
| AcceptedEvent | Informs that port was successfully bound and got a specified connection id. |
| BindCommand | Request browser port binding. |
| BindReturn | Request browser port binding. |
| UnbindCommand | Request browser port unbinding. |
| UnbindReturn | Request browser port unbinding. |