Module chrome_remote_interface_model::browser [−][src]
Browser only.The Browser domain defines methods and events for browser managing.
Structs
| Bounds | experimentalBrowser window bounds information |
| BoundsBuilder | experimental |
| BrowserContextId | experimental |
| Bucket | experimentalChrome histogram bucket. |
| CloseCommand | Close browser gracefully. |
| CloseReturn | Close browser gracefully. |
| CrashCommand | experimentalCrashes browser on the main thread. |
| CrashGpuProcessCommand | experimentalCrashes GPU process. |
| CrashGpuProcessReturn | experimentalCrashes GPU process. |
| CrashReturn | experimentalCrashes browser on the main thread. |
| ExecuteBrowserCommandCommand | experimentalInvoke custom browser commands used by telemetry. |
| ExecuteBrowserCommandReturn | experimentalInvoke custom browser commands used by telemetry. |
| GetBrowserCommandLineCommand | experimentalReturns the command line switches for the browser process if, and only if --enable-automation is on the commandline. |
| GetBrowserCommandLineReturn | experimentalReturns the command line switches for the browser process if, and only if --enable-automation is on the commandline. |
| GetHistogramCommand | experimentalGet a Chrome histogram by name. |
| GetHistogramReturn | experimentalGet a Chrome histogram by name. |
| GetHistogramsCommand | experimentalGet Chrome histograms. |
| GetHistogramsReturn | experimentalGet Chrome histograms. |
| GetVersionCommand | Returns version information. |
| GetVersionReturn | Returns version information. |
| GetVersionReturnBuilder | |
| GetWindowBoundsCommand | experimentalGet position and size of the browser window. |
| GetWindowBoundsReturn | experimentalGet position and size of the browser window. |
| GetWindowForTargetCommand | experimentalGet the browser window that contains the devtools target. |
| GetWindowForTargetReturn | experimentalGet the browser window that contains the devtools target. |
| GrantPermissionsCommand | experimentalGrant specific permissions to the given origin and reject all others. |
| GrantPermissionsReturn | experimentalGrant specific permissions to the given origin and reject all others. |
| Histogram | experimentalChrome histogram. |
| HistogramBuilder | experimental |
| PermissionDescriptor | experimentalDefinition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dictdef-permissiondescriptor. |
| PermissionDescriptorBuilder | experimental |
| ResetPermissionsCommand | experimentalReset all permission management for all origins. |
| ResetPermissionsReturn | experimentalReset all permission management for all origins. |
| SetDockTileCommand | experimentalSet dock tile details, platform-specific. |
| SetDockTileReturn | experimentalSet dock tile details, platform-specific. |
| SetDownloadBehaviorCommand | experimentalSet the behavior when downloading a file. |
| SetDownloadBehaviorReturn | experimentalSet the behavior when downloading a file. |
| SetPermissionCommand | experimentalSet permission settings for given origin. |
| SetPermissionCommandBuilder | experimental |
| SetPermissionReturn | experimentalSet permission settings for given origin. |
| SetWindowBoundsCommand | experimentalSet position and/or size of the browser window. |
| SetWindowBoundsReturn | experimentalSet position and/or size of the browser window. |
| WindowId | experimental |
Enums
| BrowserCommandId | experimental |
| PermissionSetting | experimental |
| PermissionType | experimental |
| SetDownloadBehaviorCommandBehavior | |
| WindowState | experimental |