Struct chrome_remote_interface_model::dom_snapshot::DomNodeBuilder [−][src]
experimental and DOMSnapshot and CSS and DOM and DOMDebugger and Page only.Implementations
impl DomNodeBuilder[src]
pub fn node_type(&mut self, v: u32) -> &mut Self[src]
Node's nodeType.
pub fn node_name(&mut self, v: String) -> &mut Self[src]
Node's nodeName.
pub fn node_value(&mut self, v: String) -> &mut Self[src]
Node's nodeValue.
pub fn text_value(&mut self, v: String) -> &mut Self[src]
Only set for textarea elements, contains the text value.
pub fn input_value(&mut self, v: String) -> &mut Self[src]
Only set for input elements, contains the input's associated text value.
pub fn input_checked(&mut self, v: bool) -> &mut Self[src]
Only set for radio and checkbox input elements, indicates if the element has been checked
pub fn option_selected(&mut self, v: bool) -> &mut Self[src]
Only set for option elements, indicates if the element has been selected
pub fn backend_node_id(&mut self, v: BackendNodeId) -> &mut Self[src]
Node's id, corresponds to DOM.Node.backendNodeId.
pub fn child_node_indexes(&mut self, v: Vec<u32>) -> &mut Self[src]
The indexes of the node's child nodes in the domNodes array returned by getSnapshot, if
any.
pub fn attributes(&mut self, v: Vec<NameValue>) -> &mut Self[src]
Attributes of an Element node.
pub fn pseudo_element_indexes(&mut self, v: Vec<u32>) -> &mut Self[src]
Indexes of pseudo elements associated with this node in the domNodes array returned by
getSnapshot, if any.
pub fn layout_node_index(&mut self, v: u32) -> &mut Self[src]
The index of the node's related layout tree node in the layoutTreeNodes array returned by
getSnapshot, if any.
pub fn document_url(&mut self, v: String) -> &mut Self[src]
Document URL that Document or FrameOwner node points to.
pub fn base_url(&mut self, v: String) -> &mut Self[src]
Base URL that Document or FrameOwner node uses for URL completion.
pub fn content_language(&mut self, v: String) -> &mut Self[src]
Only set for documents, contains the document's content language.
pub fn document_encoding(&mut self, v: String) -> &mut Self[src]
Only set for documents, contains the document's character set encoding.
pub fn public_id(&mut self, v: String) -> &mut Self[src]
DocumentType node's publicId.
pub fn system_id(&mut self, v: String) -> &mut Self[src]
DocumentType node's systemId.
pub fn frame_id(&mut self, v: FrameId) -> &mut Self[src]
Frame ID for frame owner elements and also for the document node.
pub fn content_document_index(&mut self, v: u32) -> &mut Self[src]
The index of a frame owner element's content document in the domNodes array returned by
getSnapshot, if any.
pub fn pseudo_type(&mut self, v: PseudoType) -> &mut Self[src]
Type of a pseudo element node.
pub fn shadow_root_type(&mut self, v: ShadowRootType) -> &mut Self[src]
Shadow root type.
pub fn is_clickable(&mut self, v: bool) -> &mut Self[src]
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
pub fn event_listeners(&mut self, v: Vec<EventListener>) -> &mut Self[src]
Details of the node's event listeners, if any.
pub fn current_source_url(&mut self, v: String) -> &mut Self[src]
The selected url for nodes with a srcset attribute.
pub fn origin_url(&mut self, v: String) -> &mut Self[src]
The url of the script (if any) that generates this node.
pub fn scroll_offset_x(&mut self, v: f64) -> &mut Self[src]
Scroll offsets, set when this node is a Document.
pub fn scroll_offset_y(&mut self, v: f64) -> &mut Self[src]
pub fn build(&mut self) -> Result<DomNode, &'static str>[src]