Struct chrome_remote_interface_model::dom_snapshot::LayoutTreeSnapshot [−][src]
experimental and DOMSnapshot and CSS and DOM and DOMDebugger and Page only.Table of details of an element in the DOM tree with a LayoutObject.
Implementations
impl LayoutTreeSnapshot[src]
pub fn builder() -> LayoutTreeSnapshotBuilder[src]
pub fn node_index(&self) -> &[u32]ⓘ[src]
Index of the corresponding node in the NodeTreeSnapshot array returned by captureSnapshot.
pub fn styles(&self) -> &[ArrayOfStrings]ⓘ[src]
Array of indexes specifying computed style strings, filtered according to the computedStyles parameter passed to captureSnapshot.
pub fn bounds(&self) -> &[Rectangle]ⓘ[src]
The absolute position bounding box.
pub fn text(&self) -> &[StringIndex]ⓘ[src]
Contents of the LayoutText, if any.
pub fn stacking_contexts(&self) -> &RareBooleanData[src]
Stacking context information.
pub fn paint_orders(&self) -> Option<&Vec<u32>>[src]
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.
pub fn offset_rects(&self) -> Option<&Vec<Rectangle>>[src]
The offset rect of nodes. Only available when includeDOMRects is set to true
pub fn scroll_rects(&self) -> Option<&Vec<Rectangle>>[src]
The scroll rect of nodes. Only available when includeDOMRects is set to true
pub fn client_rects(&self) -> Option<&Vec<Rectangle>>[src]
The client rect of nodes. Only available when includeDOMRects is set to true