Enum chrome_remote_interface_model::Event[][src]

pub enum Event {
    AnimationAnimationCanceled(AnimationCanceledEvent),
    AnimationAnimationCreated(AnimationCreatedEvent),
    AnimationAnimationStarted(AnimationStartedEvent),
    ApplicationCacheApplicationCacheStatusUpdated(ApplicationCacheStatusUpdatedEvent),
    ApplicationCacheNetworkStateUpdated(NetworkStateUpdatedEvent),
    AuditsIssueAdded(IssueAddedEvent),
    BackgroundServiceRecordingStateChanged(RecordingStateChangedEvent),
    BackgroundServiceBackgroundServiceEventReceived(BackgroundServiceEventReceivedEvent),
    CssFontsUpdated(FontsUpdatedEvent),
    CssMediaQueryResultChanged(MediaQueryResultChangedEvent),
    CssStyleSheetAdded(StyleSheetAddedEvent),
    CssStyleSheetChanged(StyleSheetChangedEvent),
    CssStyleSheetRemoved(StyleSheetRemovedEvent),
    CastSinksUpdated(SinksUpdatedEvent),
    CastIssueUpdated(IssueUpdatedEvent),
    DomAttributeModified(AttributeModifiedEvent),
    DomAttributeRemoved(AttributeRemovedEvent),
    DomCharacterDataModified(CharacterDataModifiedEvent),
    DomChildNodeCountUpdated(ChildNodeCountUpdatedEvent),
    DomChildNodeInserted(ChildNodeInsertedEvent),
    DomChildNodeRemoved(ChildNodeRemovedEvent),
    DomDistributedNodesUpdated(DistributedNodesUpdatedEvent),
    DomDocumentUpdated(DocumentUpdatedEvent),
    DomInlineStyleInvalidated(InlineStyleInvalidatedEvent),
    DomPseudoElementAdded(PseudoElementAddedEvent),
    DomPseudoElementRemoved(PseudoElementRemovedEvent),
    DomSetChildNodes(SetChildNodesEvent),
    DomShadowRootPopped(ShadowRootPoppedEvent),
    DomShadowRootPushed(ShadowRootPushedEvent),
    DomStorageDomStorageItemAdded(DomStorageItemAddedEvent),
    DomStorageDomStorageItemRemoved(DomStorageItemRemovedEvent),
    DomStorageDomStorageItemUpdated(DomStorageItemUpdatedEvent),
    DomStorageDomStorageItemsCleared(DomStorageItemsClearedEvent),
    DatabaseAddDatabase(AddDatabaseEvent),
    EmulationVirtualTimeBudgetExpired(VirtualTimeBudgetExpiredEvent),
    HeadlessExperimentalNeedsBeginFramesChanged(NeedsBeginFramesChangedEvent),
    InspectorDetached(DetachedEvent),
    InspectorTargetCrashed(TargetCrashedEvent),
    InspectorTargetReloadedAfterCrash(TargetReloadedAfterCrashEvent),
    LayerTreeLayerPainted(LayerPaintedEvent),
    LayerTreeLayerTreeDidChange(LayerTreeDidChangeEvent),
    LogEntryAdded(EntryAddedEvent),
    NetworkDataReceived(DataReceivedEvent),
    NetworkEventSourceMessageReceived(EventSourceMessageReceivedEvent),
    NetworkLoadingFailed(LoadingFailedEvent),
    NetworkLoadingFinished(LoadingFinishedEvent),
    NetworkRequestIntercepted(RequestInterceptedEvent),
    NetworkRequestServedFromCache(RequestServedFromCacheEvent),
    NetworkRequestWillBeSent(RequestWillBeSentEvent),
    NetworkResourceChangedPriority(ResourceChangedPriorityEvent),
    NetworkSignedExchangeReceived(SignedExchangeReceivedEvent),
    NetworkResponseReceived(ResponseReceivedEvent),
    NetworkWebSocketClosed(WebSocketClosedEvent),
    NetworkWebSocketCreated(WebSocketCreatedEvent),
    NetworkWebSocketFrameError(WebSocketFrameErrorEvent),
    NetworkWebSocketFrameReceived(WebSocketFrameReceivedEvent),
    NetworkWebSocketFrameSent(WebSocketFrameSentEvent),
    NetworkWebSocketHandshakeResponseReceived(WebSocketHandshakeResponseReceivedEvent),
    NetworkWebSocketWillSendHandshakeRequest(WebSocketWillSendHandshakeRequestEvent),
    NetworkRequestWillBeSentExtraInfo(RequestWillBeSentExtraInfoEvent),
    NetworkResponseReceivedExtraInfo(ResponseReceivedExtraInfoEvent),
    OverlayInspectNodeRequested(InspectNodeRequestedEvent),
    OverlayNodeHighlightRequested(NodeHighlightRequestedEvent),
    OverlayScreenshotRequested(ScreenshotRequestedEvent),
    OverlayInspectModeCanceled(InspectModeCanceledEvent),
    PageDomContentEventFired(DomContentEventFiredEvent),
    PageFileChooserOpened(FileChooserOpenedEvent),
    PageFrameAttached(FrameAttachedEvent),
    PageFrameClearedScheduledNavigation(FrameClearedScheduledNavigationEvent),
    PageFrameDetached(FrameDetachedEvent),
    PageFrameNavigated(FrameNavigatedEvent),
    PageFrameResized(FrameResizedEvent),
    PageFrameRequestedNavigation(FrameRequestedNavigationEvent),
    PageFrameScheduledNavigation(FrameScheduledNavigationEvent),
    PageFrameStartedLoading(FrameStartedLoadingEvent),
    PageFrameStoppedLoading(FrameStoppedLoadingEvent),
    PageDownloadWillBegin(DownloadWillBeginEvent),
    PageDownloadProgress(DownloadProgressEvent),
    PageInterstitialHidden(InterstitialHiddenEvent),
    PageInterstitialShown(InterstitialShownEvent),
    PageJavascriptDialogClosed(JavascriptDialogClosedEvent),
    PageJavascriptDialogOpening(JavascriptDialogOpeningEvent),
    PageLifecycleEvent(LifecycleEventEvent),
    PageLoadEventFired(LoadEventFiredEvent),
    PageNavigatedWithinDocument(NavigatedWithinDocumentEvent),
    PageScreencastFrame(ScreencastFrameEvent),
    PageScreencastVisibilityChanged(ScreencastVisibilityChangedEvent),
    PageWindowOpen(WindowOpenEvent),
    PageCompilationCacheProduced(CompilationCacheProducedEvent),
    PerformanceMetrics(MetricsEvent),
    SecurityCertificateError(CertificateErrorEvent),
    SecurityVisibleSecurityStateChanged(VisibleSecurityStateChangedEvent),
    SecuritySecurityStateChanged(SecurityStateChangedEvent),
    ServiceWorkerWorkerErrorReported(WorkerErrorReportedEvent),
    ServiceWorkerWorkerRegistrationUpdated(WorkerRegistrationUpdatedEvent),
    ServiceWorkerWorkerVersionUpdated(WorkerVersionUpdatedEvent),
    StorageCacheStorageContentUpdated(CacheStorageContentUpdatedEvent),
    StorageCacheStorageListUpdated(CacheStorageListUpdatedEvent),
    StorageIndexedDbContentUpdated(IndexedDbContentUpdatedEvent),
    StorageIndexedDbListUpdated(IndexedDbListUpdatedEvent),
    TargetAttachedToTarget(AttachedToTargetEvent),
    TargetDetachedFromTarget(DetachedFromTargetEvent),
    TargetReceivedMessageFromTarget(ReceivedMessageFromTargetEvent),
    TargetTargetCreated(TargetCreatedEvent),
    TargetTargetDestroyed(TargetDestroyedEvent),
    TargetTargetCrashed(TargetCrashedEvent),
    TargetTargetInfoChanged(TargetInfoChangedEvent),
    TetheringAccepted(AcceptedEvent),
    TracingBufferUsage(BufferUsageEvent),
    TracingDataCollected(DataCollectedEvent),
    TracingTracingComplete(TracingCompleteEvent),
    FetchRequestPaused(RequestPausedEvent),
    FetchAuthRequired(AuthRequiredEvent),
    WebAudioContextCreated(ContextCreatedEvent),
    WebAudioContextWillBeDestroyed(ContextWillBeDestroyedEvent),
    WebAudioContextChanged(ContextChangedEvent),
    WebAudioAudioListenerCreated(AudioListenerCreatedEvent),
    WebAudioAudioListenerWillBeDestroyed(AudioListenerWillBeDestroyedEvent),
    WebAudioAudioNodeCreated(AudioNodeCreatedEvent),
    WebAudioAudioNodeWillBeDestroyed(AudioNodeWillBeDestroyedEvent),
    WebAudioAudioParamCreated(AudioParamCreatedEvent),
    WebAudioAudioParamWillBeDestroyed(AudioParamWillBeDestroyedEvent),
    WebAudioNodesConnected(NodesConnectedEvent),
    WebAudioNodesDisconnected(NodesDisconnectedEvent),
    WebAudioNodeParamConnected(NodeParamConnectedEvent),
    WebAudioNodeParamDisconnected(NodeParamDisconnectedEvent),
    MediaPlayerPropertiesChanged(PlayerPropertiesChangedEvent),
    MediaPlayerEventsAdded(PlayerEventsAddedEvent),
    MediaPlayerMessagesLogged(PlayerMessagesLoggedEvent),
    MediaPlayerErrorsRaised(PlayerErrorsRaisedEvent),
    MediaPlayersCreated(PlayersCreatedEvent),
    ConsoleMessageAdded(MessageAddedEvent),
    DebuggerBreakpointResolved(BreakpointResolvedEvent),
    DebuggerPaused(PausedEvent),
    DebuggerResumed(ResumedEvent),
    DebuggerScriptFailedToParse(ScriptFailedToParseEvent),
    DebuggerScriptParsed(ScriptParsedEvent),
    HeapProfilerAddHeapSnapshotChunk(AddHeapSnapshotChunkEvent),
    HeapProfilerHeapStatsUpdate(HeapStatsUpdateEvent),
    HeapProfilerLastSeenObjectId(LastSeenObjectIdEvent),
    HeapProfilerReportHeapSnapshotProgress(ReportHeapSnapshotProgressEvent),
    HeapProfilerResetProfiles(ResetProfilesEvent),
    ProfilerConsoleProfileFinished(ConsoleProfileFinishedEvent),
    ProfilerConsoleProfileStarted(ConsoleProfileStartedEvent),
    ProfilerPreciseCoverageDeltaUpdate(PreciseCoverageDeltaUpdateEvent),
    RuntimeBindingCalled(BindingCalledEvent),
    RuntimeConsoleApiCalled(ConsoleApiCalledEvent),
    RuntimeExceptionRevoked(ExceptionRevokedEvent),
    RuntimeExceptionThrown(ExceptionThrownEvent),
    RuntimeExecutionContextCreated(ExecutionContextCreatedEvent),
    RuntimeExecutionContextDestroyed(ExecutionContextDestroyedEvent),
    RuntimeExecutionContextsCleared(ExecutionContextsClearedEvent),
    RuntimeInspectRequested(InspectRequestedEvent),
    Unknown(StringJsonValue),
}

Chrome DevTools Protocol event.

Variants

AnimationAnimationCanceled(AnimationCanceledEvent)
This is supported on crate features experimental and Animation and Runtime and DOM only.

Event for when an animation has been cancelled.

AnimationAnimationCreated(AnimationCreatedEvent)
This is supported on crate features experimental and Animation and Runtime and DOM only.

Event for each animation that has been created.

AnimationAnimationStarted(AnimationStartedEvent)
This is supported on crate features experimental and Animation and Runtime and DOM only.

Event for animation that has been started.

ApplicationCacheApplicationCacheStatusUpdated(ApplicationCacheStatusUpdatedEvent)
This is supported on crate features experimental and ApplicationCache and Page only.
ApplicationCacheNetworkStateUpdated(NetworkStateUpdatedEvent)
This is supported on crate features experimental and ApplicationCache and Page only.
AuditsIssueAdded(IssueAddedEvent)
This is supported on crate features experimental and Audits and Network only.
BackgroundServiceRecordingStateChanged(RecordingStateChangedEvent)
This is supported on crate features experimental and BackgroundService only.

Called when the recording state for the service has been updated.

BackgroundServiceBackgroundServiceEventReceived(BackgroundServiceEventReceivedEvent)
This is supported on crate features experimental and BackgroundService only.

Called with all existing backgroundServiceEvents when enabled, and all new events afterwards if enabled and recording.

CssFontsUpdated(FontsUpdatedEvent)
This is supported on crate features experimental and CSS and DOM and Page only.

Fires whenever a web font is updated. A non-empty font parameter indicates a successfully loaded web font

CssMediaQueryResultChanged(MediaQueryResultChangedEvent)
This is supported on crate features experimental and CSS and DOM and Page only.

Fires whenever a MediaQuery result changes (for example, after a browser window has been resized.) The current implementation considers only viewport-dependent media features.

CssStyleSheetAdded(StyleSheetAddedEvent)
This is supported on crate features experimental and CSS and DOM and Page only.

Fired whenever an active document stylesheet is added.

CssStyleSheetChanged(StyleSheetChangedEvent)
This is supported on crate features experimental and CSS and DOM and Page only.

Fired whenever a stylesheet is changed as a result of the client operation.

CssStyleSheetRemoved(StyleSheetRemovedEvent)
This is supported on crate features experimental and CSS and DOM and Page only.

Fired whenever an active document stylesheet is removed.

CastSinksUpdated(SinksUpdatedEvent)
This is supported on crate features experimental and Cast only.

This is fired whenever the list of available sinks changes. A sink is a device or a software surface that you can cast to.

CastIssueUpdated(IssueUpdatedEvent)
This is supported on crate features experimental and Cast only.

This is fired whenever the outstanding issue/error message changes. |issueMessage| is empty if there is no issue.

DomAttributeModified(AttributeModifiedEvent)
This is supported on crate features DOM and Runtime only.

Fired when Element's attribute is modified.

DomAttributeRemoved(AttributeRemovedEvent)
This is supported on crate features DOM and Runtime only.

Fired when Element's attribute is removed.

DomCharacterDataModified(CharacterDataModifiedEvent)
This is supported on crate features DOM and Runtime only.

Mirrors DOMCharacterDataModified event.

DomChildNodeCountUpdated(ChildNodeCountUpdatedEvent)
This is supported on crate features DOM and Runtime only.

Fired when Container's child node count has changed.

DomChildNodeInserted(ChildNodeInsertedEvent)
This is supported on crate features DOM and Runtime only.

Mirrors DOMNodeInserted event.

DomChildNodeRemoved(ChildNodeRemovedEvent)
This is supported on crate features DOM and Runtime only.

Mirrors DOMNodeRemoved event.

DomDistributedNodesUpdated(DistributedNodesUpdatedEvent)
This is supported on crate features DOM and Runtime and experimental only.

Called when distrubution is changed.

DomDocumentUpdated(DocumentUpdatedEvent)
This is supported on crate features DOM and Runtime only.

Fired when Document has been totally updated. Node ids are no longer valid.

DomInlineStyleInvalidated(InlineStyleInvalidatedEvent)
This is supported on crate features DOM and Runtime and experimental only.

Fired when Element's inline style is modified via a CSS property modification.

DomPseudoElementAdded(PseudoElementAddedEvent)
This is supported on crate features DOM and Runtime and experimental only.

Called when a pseudo element is added to an element.

DomPseudoElementRemoved(PseudoElementRemovedEvent)
This is supported on crate features DOM and Runtime and experimental only.

Called when a pseudo element is removed from an element.

DomSetChildNodes(SetChildNodesEvent)
This is supported on crate features DOM and Runtime only.

Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids.

DomShadowRootPopped(ShadowRootPoppedEvent)
This is supported on crate features DOM and Runtime and experimental only.

Called when shadow root is popped from the element.

DomShadowRootPushed(ShadowRootPushedEvent)
This is supported on crate features DOM and Runtime and experimental only.

Called when shadow root is pushed into the element.

DomStorageDomStorageItemAdded(DomStorageItemAddedEvent)
This is supported on crate features experimental and DOMStorage only.
DomStorageDomStorageItemRemoved(DomStorageItemRemovedEvent)
This is supported on crate features experimental and DOMStorage only.
DomStorageDomStorageItemUpdated(DomStorageItemUpdatedEvent)
This is supported on crate features experimental and DOMStorage only.
DomStorageDomStorageItemsCleared(DomStorageItemsClearedEvent)
This is supported on crate features experimental and DOMStorage only.
DatabaseAddDatabase(AddDatabaseEvent)
This is supported on crate features experimental and Database only.
EmulationVirtualTimeBudgetExpired(VirtualTimeBudgetExpiredEvent)
This is supported on crate features Emulation and DOM and Page and Runtime and experimental only.

Notification sent after the virtual time budget for the current VirtualTimePolicy has run out.

HeadlessExperimentalNeedsBeginFramesChanged(NeedsBeginFramesChangedEvent)
👎 Deprecated
This is supported on crate features experimental and HeadlessExperimental and Page and Runtime only.

Issued when the target starts or stops needing BeginFrames. Deprecated. Issue beginFrame unconditionally instead and use result from beginFrame to detect whether the frames were suppressed.

InspectorDetached(DetachedEvent)
This is supported on crate features experimental and Inspector only.

Fired when remote debugging connection is about to be terminated. Contains detach reason.

InspectorTargetCrashed(TargetCrashedEvent)
This is supported on crate features experimental and Inspector only.

Fired when debugging target has crashed

InspectorTargetReloadedAfterCrash(TargetReloadedAfterCrashEvent)
This is supported on crate features experimental and Inspector only.

Fired when debugging target has reloaded after crash

LayerTreeLayerPainted(LayerPaintedEvent)
This is supported on crate features experimental and LayerTree and DOM only.
LayerTreeLayerTreeDidChange(LayerTreeDidChangeEvent)
This is supported on crate features experimental and LayerTree and DOM only.
LogEntryAdded(EntryAddedEvent)
This is supported on crate features Log and Runtime and Network only.

Issued when new message was logged.

NetworkDataReceived(DataReceivedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when data chunk was received over the network.

NetworkEventSourceMessageReceived(EventSourceMessageReceivedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when EventSource message is received.

NetworkLoadingFailed(LoadingFailedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when HTTP request has failed to load.

NetworkLoadingFinished(LoadingFinishedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when HTTP request has finished loading.

NetworkRequestIntercepted(RequestInterceptedEvent)
👎 Deprecated
This is supported on crate features Network and Debugger and Runtime and Security and experimental only.

Details of an intercepted HTTP request, which must be either allowed, blocked, modified or mocked. Deprecated, use Fetch.requestPaused instead.

NetworkRequestServedFromCache(RequestServedFromCacheEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired if request ended up loading from cache.

NetworkRequestWillBeSent(RequestWillBeSentEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when page is about to send HTTP request.

NetworkResourceChangedPriority(ResourceChangedPriorityEvent)
This is supported on crate features Network and Debugger and Runtime and Security and experimental only.

Fired when resource loading priority is changed

NetworkSignedExchangeReceived(SignedExchangeReceivedEvent)
This is supported on crate features Network and Debugger and Runtime and Security and experimental only.

Fired when a signed exchange was received over the network

NetworkResponseReceived(ResponseReceivedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when HTTP response is available.

NetworkWebSocketClosed(WebSocketClosedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when WebSocket is closed.

NetworkWebSocketCreated(WebSocketCreatedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired upon WebSocket creation.

NetworkWebSocketFrameError(WebSocketFrameErrorEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when WebSocket message error occurs.

NetworkWebSocketFrameReceived(WebSocketFrameReceivedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when WebSocket message is received.

NetworkWebSocketFrameSent(WebSocketFrameSentEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when WebSocket message is sent.

NetworkWebSocketHandshakeResponseReceived(WebSocketHandshakeResponseReceivedEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when WebSocket handshake response becomes available.

NetworkWebSocketWillSendHandshakeRequest(WebSocketWillSendHandshakeRequestEvent)
This is supported on crate features Network and Debugger and Runtime and Security only.

Fired when WebSocket is about to initiate handshake.

NetworkRequestWillBeSentExtraInfo(RequestWillBeSentExtraInfoEvent)
This is supported on crate features Network and Debugger and Runtime and Security and experimental only.

Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request.

NetworkResponseReceivedExtraInfo(ResponseReceivedExtraInfoEvent)
This is supported on crate features Network and Debugger and Runtime and Security and experimental only.

Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived.

OverlayInspectNodeRequested(InspectNodeRequestedEvent)
This is supported on crate features experimental and Overlay and DOM and Page and Runtime only.

Fired when the node should be inspected. This happens after call to setInspectMode or when user manually inspects an element.

OverlayNodeHighlightRequested(NodeHighlightRequestedEvent)
This is supported on crate features experimental and Overlay and DOM and Page and Runtime only.

Fired when the node should be highlighted. This happens after call to setInspectMode.

OverlayScreenshotRequested(ScreenshotRequestedEvent)
This is supported on crate features experimental and Overlay and DOM and Page and Runtime only.

Fired when user asks to capture screenshot of some area on the page.

OverlayInspectModeCanceled(InspectModeCanceledEvent)
This is supported on crate features experimental and Overlay and DOM and Page and Runtime only.

Fired when user cancels the inspect mode.

PageDomContentEventFired(DomContentEventFiredEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.
PageFileChooserOpened(FileChooserOpenedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Emitted only when page.interceptFileChooser is enabled.

PageFrameAttached(FrameAttachedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when frame has been attached to its parent.

PageFrameClearedScheduledNavigation(FrameClearedScheduledNavigationEvent)
👎 Deprecated
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when frame no longer has a scheduled navigation.

PageFrameDetached(FrameDetachedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when frame has been detached from its parent.

PageFrameNavigated(FrameNavigatedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired once navigation of the frame has completed. Frame is now associated with the new loader.

PageFrameResized(FrameResizedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.
PageFrameRequestedNavigation(FrameRequestedNavigationEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when a renderer-initiated navigation is requested. Navigation may still be cancelled after the event is issued.

PageFrameScheduledNavigation(FrameScheduledNavigationEvent)
👎 Deprecated
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when frame schedules a potential navigation.

PageFrameStartedLoading(FrameStartedLoadingEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when frame has started loading.

PageFrameStoppedLoading(FrameStoppedLoadingEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when frame has stopped loading.

PageDownloadWillBegin(DownloadWillBeginEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when page is about to start a download.

PageDownloadProgress(DownloadProgressEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when download makes progress. Last call has |done| == true.

PageInterstitialHidden(InterstitialHiddenEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when interstitial page was hidden

PageInterstitialShown(InterstitialShownEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when interstitial page was shown

PageJavascriptDialogClosed(JavascriptDialogClosedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been closed.

PageJavascriptDialogOpening(JavascriptDialogOpeningEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open.

PageLifecycleEvent(LifecycleEventEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired for top level page lifecycle events such as navigation, load, paint, etc.

PageLoadEventFired(LoadEventFiredEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.
PageNavigatedWithinDocument(NavigatedWithinDocumentEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when same-document navigation happens, e.g. due to history API usage or anchor navigation.

PageScreencastFrame(ScreencastFrameEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Compressed image data requested by the startScreencast.

PageScreencastVisibilityChanged(ScreencastVisibilityChangedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Fired when the page with currently enabled screencast was shown or hidden `.

PageWindowOpen(WindowOpenEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime only.

Fired when a new window is going to be opened, via window.open(), link click, form submission, etc.

PageCompilationCacheProduced(CompilationCacheProducedEvent)
This is supported on crate features Page and Debugger and DOM and IO and Network and Runtime and experimental only.

Issued for every compilation cache generated. Is only available if Page.setGenerateCompilationCache is enabled.

PerformanceMetrics(MetricsEvent)
This is supported on crate feature Performance only.

Current values of the metrics.

SecurityCertificateError(CertificateErrorEvent)
👎 Deprecated
This is supported on crate feature Security only.

There is a certificate error. If overriding certificate errors is enabled, then it should be handled with the handleCertificateError command. Note: this event does not fire if the certificate error has been allowed internally. Only one client per target should override certificate errors at the same time.

SecurityVisibleSecurityStateChanged(VisibleSecurityStateChangedEvent)
This is supported on crate features Security and experimental only.

The security state of the page changed.

SecuritySecurityStateChanged(SecurityStateChangedEvent)
This is supported on crate feature Security only.

The security state of the page changed.

ServiceWorkerWorkerErrorReported(WorkerErrorReportedEvent)
This is supported on crate features experimental and ServiceWorker and Target only.
ServiceWorkerWorkerRegistrationUpdated(WorkerRegistrationUpdatedEvent)
This is supported on crate features experimental and ServiceWorker and Target only.
ServiceWorkerWorkerVersionUpdated(WorkerVersionUpdatedEvent)
This is supported on crate features experimental and ServiceWorker and Target only.
StorageCacheStorageContentUpdated(CacheStorageContentUpdatedEvent)
This is supported on crate features experimental and Storage and Browser and Network only.

A cache's contents have been modified.

StorageCacheStorageListUpdated(CacheStorageListUpdatedEvent)
This is supported on crate features experimental and Storage and Browser and Network only.

A cache has been added/deleted.

StorageIndexedDbContentUpdated(IndexedDbContentUpdatedEvent)
This is supported on crate features experimental and Storage and Browser and Network only.

The origin's IndexedDB object store has been modified.

StorageIndexedDbListUpdated(IndexedDbListUpdatedEvent)
This is supported on crate features experimental and Storage and Browser and Network only.

The origin's IndexedDB database list has been modified.

TargetAttachedToTarget(AttachedToTargetEvent)
This is supported on crate features Target and experimental only.

Issued when attached to target because of auto-attach or attachToTarget command.

TargetDetachedFromTarget(DetachedFromTargetEvent)
This is supported on crate features Target and experimental only.

Issued when detached from target for any reason (including detachFromTarget command). Can be issued multiple times per target if multiple sessions have been attached to it.

TargetReceivedMessageFromTarget(ReceivedMessageFromTargetEvent)
This is supported on crate feature Target only.

Notifies about a new protocol message received from the session (as reported in attachedToTarget event).

TargetTargetCreated(TargetCreatedEvent)
This is supported on crate feature Target only.

Issued when a possible inspection target is created.

TargetTargetDestroyed(TargetDestroyedEvent)
This is supported on crate feature Target only.

Issued when a target is destroyed.

TargetTargetCrashed(TargetCrashedEvent)
This is supported on crate feature Target only.

Issued when a target has crashed.

TargetTargetInfoChanged(TargetInfoChangedEvent)
This is supported on crate feature Target only.

Issued when some information about a target has changed. This only happens between targetCreated and targetDestroyed.

TetheringAccepted(AcceptedEvent)
This is supported on crate features experimental and Tethering only.

Informs that port was successfully bound and got a specified connection id.

TracingBufferUsage(BufferUsageEvent)
This is supported on crate features experimental and Tracing and IO only.
TracingDataCollected(DataCollectedEvent)
This is supported on crate features experimental and Tracing and IO only.

Contains an bucket of collected trace events. When tracing is stopped collected events will be send as a sequence of dataCollected events followed by tracingComplete event.

TracingTracingComplete(TracingCompleteEvent)
This is supported on crate features experimental and Tracing and IO only.

Signals that tracing is stopped and there is no trace buffers pending flush, all data were delivered via dataCollected events.

FetchRequestPaused(RequestPausedEvent)
This is supported on crate features Fetch and Network and IO and Page only.

Issued when the domain is enabled and the request URL matches the specified filter. The request is paused until the client responds with one of continueRequest, failRequest or fulfillRequest. The stage of the request can be determined by presence of responseErrorReason and responseStatusCode -- the request is at the response stage if either of these fields is present and in the request stage otherwise.

FetchAuthRequired(AuthRequiredEvent)
This is supported on crate features Fetch and Network and IO and Page only.

Issued when the domain is enabled with handleAuthRequests set to true. The request is paused until client responds with continueWithAuth.

WebAudioContextCreated(ContextCreatedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that a new BaseAudioContext has been created.

WebAudioContextWillBeDestroyed(ContextWillBeDestroyedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that an existing BaseAudioContext will be destroyed.

WebAudioContextChanged(ContextChangedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that existing BaseAudioContext has changed some properties (id stays the same)..

WebAudioAudioListenerCreated(AudioListenerCreatedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that the construction of an AudioListener has finished.

WebAudioAudioListenerWillBeDestroyed(AudioListenerWillBeDestroyedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that a new AudioListener has been created.

WebAudioAudioNodeCreated(AudioNodeCreatedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that a new AudioNode has been created.

WebAudioAudioNodeWillBeDestroyed(AudioNodeWillBeDestroyedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that an existing AudioNode has been destroyed.

WebAudioAudioParamCreated(AudioParamCreatedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that a new AudioParam has been created.

WebAudioAudioParamWillBeDestroyed(AudioParamWillBeDestroyedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that an existing AudioParam has been destroyed.

WebAudioNodesConnected(NodesConnectedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that two AudioNodes are connected.

WebAudioNodesDisconnected(NodesDisconnectedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that AudioNodes are disconnected. The destination can be null, and it means all the outgoing connections from the source are disconnected.

WebAudioNodeParamConnected(NodeParamConnectedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that an AudioNode is connected to an AudioParam.

WebAudioNodeParamDisconnected(NodeParamDisconnectedEvent)
This is supported on crate features experimental and WebAudio only.

Notifies that an AudioNode is disconnected to an AudioParam.

MediaPlayerPropertiesChanged(PlayerPropertiesChangedEvent)
This is supported on crate features experimental and Media only.

This can be called multiple times, and can be used to set / override / remove player properties. A null propValue indicates removal.

MediaPlayerEventsAdded(PlayerEventsAddedEvent)
This is supported on crate features experimental and Media only.

Send events as a list, allowing them to be batched on the browser for less congestion. If batched, events must ALWAYS be in chronological order.

MediaPlayerMessagesLogged(PlayerMessagesLoggedEvent)
This is supported on crate features experimental and Media only.

Send a list of any messages that need to be delivered.

MediaPlayerErrorsRaised(PlayerErrorsRaisedEvent)
This is supported on crate features experimental and Media only.

Send a list of any errors that need to be delivered.

MediaPlayersCreated(PlayersCreatedEvent)
This is supported on crate features experimental and Media only.

Called whenever a player is created, or when a new agent joins and recieves a list of active players. If an agent is restored, it will recieve the full list of player ids and all events again.

ConsoleMessageAdded(MessageAddedEvent)
👎 Deprecated
This is supported on crate features Console and Runtime only.

Issued when new console message is added.

DebuggerBreakpointResolved(BreakpointResolvedEvent)
This is supported on crate features Debugger and Runtime only.

Fired when breakpoint is resolved to an actual script and location.

DebuggerPaused(PausedEvent)
This is supported on crate features Debugger and Runtime only.

Fired when the virtual machine stopped on breakpoint or exception or any other stop criteria.

DebuggerResumed(ResumedEvent)
This is supported on crate features Debugger and Runtime only.

Fired when the virtual machine resumed execution.

DebuggerScriptFailedToParse(ScriptFailedToParseEvent)
This is supported on crate features Debugger and Runtime only.

Fired when virtual machine fails to parse the script.

DebuggerScriptParsed(ScriptParsedEvent)
This is supported on crate features Debugger and Runtime only.

Fired when virtual machine parses script. This event is also fired for all known and uncollected scripts upon enabling debugger.

HeapProfilerAddHeapSnapshotChunk(AddHeapSnapshotChunkEvent)
This is supported on crate features experimental and HeapProfiler and Runtime only.
HeapProfilerHeapStatsUpdate(HeapStatsUpdateEvent)
This is supported on crate features experimental and HeapProfiler and Runtime only.

If heap objects tracking has been started then backend may send update for one or more fragments

HeapProfilerLastSeenObjectId(LastSeenObjectIdEvent)
This is supported on crate features experimental and HeapProfiler and Runtime only.

If heap objects tracking has been started then backend regularly sends a current value for last seen object id and corresponding timestamp. If the were changes in the heap since last event then one or more heapStatsUpdate events will be sent before a new lastSeenObjectId event.

HeapProfilerReportHeapSnapshotProgress(ReportHeapSnapshotProgressEvent)
This is supported on crate features experimental and HeapProfiler and Runtime only.
HeapProfilerResetProfiles(ResetProfilesEvent)
This is supported on crate features experimental and HeapProfiler and Runtime only.
ProfilerConsoleProfileFinished(ConsoleProfileFinishedEvent)
This is supported on crate features Profiler and Runtime and Debugger only.
ProfilerConsoleProfileStarted(ConsoleProfileStartedEvent)
This is supported on crate features Profiler and Runtime and Debugger only.

Sent when new profile recording is started using console.profile() call.

ProfilerPreciseCoverageDeltaUpdate(PreciseCoverageDeltaUpdateEvent)
This is supported on crate features Profiler and Runtime and Debugger and experimental only.

Reports coverage delta since the last poll (either from an event like this, or from takePreciseCoverage for the current isolate. May only be sent if precise code coverage has been started. This event can be trigged by the embedder to, for example, trigger collection of coverage data immediatelly at a certain point in time.

RuntimeBindingCalled(BindingCalledEvent)
This is supported on crate features Runtime and experimental only.

Notification is issued every time when binding is called.

RuntimeConsoleApiCalled(ConsoleApiCalledEvent)
This is supported on crate feature Runtime only.

Issued when console API was called.

RuntimeExceptionRevoked(ExceptionRevokedEvent)
This is supported on crate feature Runtime only.

Issued when unhandled exception was revoked.

RuntimeExceptionThrown(ExceptionThrownEvent)
This is supported on crate feature Runtime only.

Issued when exception was thrown and unhandled.

RuntimeExecutionContextCreated(ExecutionContextCreatedEvent)
This is supported on crate feature Runtime only.

Issued when new execution context is created.

RuntimeExecutionContextDestroyed(ExecutionContextDestroyedEvent)
This is supported on crate feature Runtime only.

Issued when execution context is destroyed.

RuntimeExecutionContextsCleared(ExecutionContextsClearedEvent)
This is supported on crate feature Runtime only.

Issued when all executionContexts were cleared in browser

RuntimeInspectRequested(InspectRequestedEvent)
This is supported on crate feature Runtime only.

Issued when object should be inspected (for example, as a result of inspect() command line API call).

Unknown(StringJsonValue)

Unknown event.