Module chrome_remote_interface_model::input [−][src]
Input only.Structs
| DispatchKeyEventCommand | Dispatches a key event to the page. |
| DispatchKeyEventCommandBuilder | |
| DispatchKeyEventReturn | Dispatches a key event to the page. |
| DispatchMouseEventCommand | Dispatches a mouse event to the page. |
| DispatchMouseEventCommandBuilder | |
| DispatchMouseEventReturn | Dispatches a mouse event to the page. |
| DispatchTouchEventCommand | Dispatches a touch event to the page. |
| DispatchTouchEventCommandBuilder | |
| DispatchTouchEventReturn | Dispatches a touch event to the page. |
| EmulateTouchFromMouseEventCommand | experimentalEmulates touch event from the mouse event parameters. |
| EmulateTouchFromMouseEventCommandBuilder | experimental |
| EmulateTouchFromMouseEventReturn | experimentalEmulates touch event from the mouse event parameters. |
| InsertTextCommand | experimentalThis method emulates inserting text that doesn't come from a key press, for example an emoji keyboard or an IME. |
| InsertTextReturn | experimentalThis method emulates inserting text that doesn't come from a key press, for example an emoji keyboard or an IME. |
| SetIgnoreInputEventsCommand | Ignores input events (useful while auditing page). |
| SetIgnoreInputEventsReturn | Ignores input events (useful while auditing page). |
| SynthesizePinchGestureCommand | experimentalSynthesizes a pinch gesture over a time period by issuing appropriate touch events. |
| SynthesizePinchGestureCommandBuilder | experimental |
| SynthesizePinchGestureReturn | experimentalSynthesizes a pinch gesture over a time period by issuing appropriate touch events. |
| SynthesizeScrollGestureCommand | experimentalSynthesizes a scroll gesture over a time period by issuing appropriate touch events. |
| SynthesizeScrollGestureCommandBuilder | experimental |
| SynthesizeScrollGestureReturn | experimentalSynthesizes a scroll gesture over a time period by issuing appropriate touch events. |
| SynthesizeTapGestureCommand | experimentalSynthesizes a tap gesture over a time period by issuing appropriate touch events. |
| SynthesizeTapGestureCommandBuilder | experimental |
| SynthesizeTapGestureReturn | experimentalSynthesizes a tap gesture over a time period by issuing appropriate touch events. |
| TimeSinceEpoch | UTC time in seconds, counted from January 1, 1970. |
| TouchPoint | |
| TouchPointBuilder |
Enums
| DispatchKeyEventCommandType | |
| DispatchMouseEventCommandPointerType | |
| DispatchMouseEventCommandType | |
| DispatchTouchEventCommandType | |
| EmulateTouchFromMouseEventCommandType | |
| GestureSourceType | experimental |
| MouseButton |