pub struct Response { /* private fields */ }Network and Debugger and Runtime and Security only.Expand description
HTTP response data.
Implementations
Sourceimpl Response
impl Response
pub fn builder() -> ResponseBuilder
Sourcepub fn url(&self) -> &str
pub fn url(&self) -> &str
Response URL. This URL can be different from CachedResource.url in case of redirect.
Sourcepub fn status_text(&self) -> &str
pub fn status_text(&self) -> &str
HTTP response status text.
Sourcepub fn headers_text(&self) -> Option<&String>
pub fn headers_text(&self) -> Option<&String>
HTTP response headers text.
Sourcepub fn request_headers(&self) -> Option<&Headers>
pub fn request_headers(&self) -> Option<&Headers>
Refined HTTP request headers that were actually transmitted over the network.
Sourcepub fn request_headers_text(&self) -> Option<&String>
pub fn request_headers_text(&self) -> Option<&String>
HTTP request headers text.
Sourcepub fn connection_reused(&self) -> bool
pub fn connection_reused(&self) -> bool
Specifies whether physical connection was actually reused for this request.
Sourcepub fn connection_id(&self) -> f64
pub fn connection_id(&self) -> f64
Physical connection id that was actually used for this request.
Sourcepub fn remote_ip_address(&self) -> Option<&String>
pub fn remote_ip_address(&self) -> Option<&String>
Remote IP address.
Sourcepub fn remote_port(&self) -> Option<&u32>
pub fn remote_port(&self) -> Option<&u32>
Remote port.
Sourcepub fn from_disk_cache(&self) -> Option<&bool>
pub fn from_disk_cache(&self) -> Option<&bool>
Specifies that the request was served from the disk cache.
Sourcepub fn from_service_worker(&self) -> Option<&bool>
pub fn from_service_worker(&self) -> Option<&bool>
Specifies that the request was served from the ServiceWorker.
Sourcepub fn from_prefetch_cache(&self) -> Option<&bool>
pub fn from_prefetch_cache(&self) -> Option<&bool>
Specifies that the request was served from the prefetch cache.
Sourcepub fn encoded_data_length(&self) -> f64
pub fn encoded_data_length(&self) -> f64
Total number of bytes received for this request so far.
Sourcepub fn timing(&self) -> Option<&ResourceTiming>
pub fn timing(&self) -> Option<&ResourceTiming>
Timing information for the given request.
Sourcepub fn service_worker_response_source(
&self,
) -> Option<&ServiceWorkerResponseSource>
pub fn service_worker_response_source( &self, ) -> Option<&ServiceWorkerResponseSource>
Response source of response from ServiceWorker.
Sourcepub fn response_time(&self) -> Option<&TimeSinceEpoch>
pub fn response_time(&self) -> Option<&TimeSinceEpoch>
The time at which the returned response was generated.
Sourcepub fn cache_storage_cache_name(&self) -> Option<&String>
pub fn cache_storage_cache_name(&self) -> Option<&String>
Cache Storage Cache Name.
Sourcepub fn security_state(&self) -> &SecurityState
pub fn security_state(&self) -> &SecurityState
Security state of the request resource.
Sourcepub fn security_details(&self) -> Option<&SecurityDetails>
pub fn security_details(&self) -> Option<&SecurityDetails>
Security details for the request.