Available on crate features
Profiler and Runtime and Debugger only.Structs
- Console
Profile Finished Event - Console
Profile Finished Event Builder - Console
Profile Started Event - Sent when new profile recording is started using console.profile() call.
- Counter
Info experimental - Collected counter information.
- Coverage
Range - Coverage data for a source range.
- Disable
Command - Disable
Counters Command experimental - Disable counters collection.
- Disable
Counters Return experimental - Disable counters collection.
- Disable
Return - Disable
Runtime Call Stats Command experimental - Disable run time call stats collection.
- Disable
Runtime Call Stats Return experimental - Disable run time call stats collection.
- Enable
Command - Enable
Counters Command experimental - Enable counters collection.
- Enable
Counters Return experimental - Enable counters collection.
- Enable
Return - Enable
Runtime Call Stats Command experimental - Enable run time call stats collection.
- Enable
Runtime Call Stats Return experimental - Enable run time call stats collection.
- Function
Coverage - Coverage data for a JavaScript function.
- GetBest
Effort Coverage Command - Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
- GetBest
Effort Coverage Return - Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
- GetCounters
Command experimental - Retrieve counters.
- GetCounters
Return experimental - Retrieve counters.
- GetRuntime
Call Stats Command experimental - Retrieve run time call stats.
- GetRuntime
Call Stats Return experimental - Retrieve run time call stats.
- Position
Tick Info - Specifies a number of samples attributed to a certain source position.
- Precise
Coverage Delta Update Event experimental - Reports coverage delta since the last poll (either from an event like this, or from
takePreciseCoveragefor the current isolate. May only be sent if precise code coverage has been started. This event can be trigged by the embedder to, for example, trigger collection of coverage data immediatelly at a certain point in time. - Profile
- Profile.
- Profile
Builder - Profile
Node - Profile node. Holds callsite information, execution statistics and child nodes.
- Profile
Node Builder - Runtime
Call Counter Info experimental - Runtime call counter information.
- Script
Coverage - Coverage data for a JavaScript script.
- Script
Type Profile experimental - Type profile data collected during runtime for a JavaScript script.
- SetSampling
Interval Command - Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.
- SetSampling
Interval Return - Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.
- Start
Command - Start
Precise Coverage Command - Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
- Start
Precise Coverage Return - Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
- Start
Return - Start
Type Profile Command experimental - Enable type profile.
- Start
Type Profile Return experimental - Enable type profile.
- Stop
Command - Stop
Precise Coverage Command - Disable precise code coverage. Disabling releases unnecessary execution count records and allows executing optimized code.
- Stop
Precise Coverage Return - Disable precise code coverage. Disabling releases unnecessary execution count records and allows executing optimized code.
- Stop
Return - Stop
Type Profile Command experimental - Disable type profile. Disabling releases type profile data collected so far.
- Stop
Type Profile Return experimental - Disable type profile. Disabling releases type profile data collected so far.
- Take
Precise Coverage Command - Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.
- Take
Precise Coverage Return - Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.
- Take
Type Profile Command experimental - Collect type profile.
- Take
Type Profile Return experimental - Collect type profile.
- Type
Object experimental - Describes a type collected during runtime.
- Type
Profile Entry experimental - Source offset and types for a parameter or return value.