Struct chrome_remote_interface_model::profiler::StartPreciseCoverageCommand [−][src]
This is supported on crate features
Profiler and Runtime and Debugger only.Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
Implementations
impl StartPreciseCoverageCommand[src]
pub fn new(
call_count: Option<bool>,
detailed: Option<bool>,
allow_triggered_updates: Option<bool>
) -> Self[src]
call_count: Option<bool>,
detailed: Option<bool>,
allow_triggered_updates: Option<bool>
) -> Self
pub fn call_count(&self) -> Option<&bool>[src]
Collect accurate call counts beyond simple 'covered' or 'not covered'.
pub fn detailed(&self) -> Option<&bool>[src]
Collect block-based coverage.
pub fn allow_triggered_updates(&self) -> Option<&bool>[src]
Allow the backend to send updates on its own initiative