pub struct CompileScriptCommand { /* private fields */ }Available on crate feature
Runtime only.Expand description
Compiles expression.
Implementations
Sourceimpl CompileScriptCommand
impl CompileScriptCommand
pub fn builder() -> CompileScriptCommandBuilder
Sourcepub fn expression(&self) -> &str
pub fn expression(&self) -> &str
Expression to compile.
Sourcepub fn source_url(&self) -> &str
pub fn source_url(&self) -> &str
Source url to be set for the script.
Sourcepub fn persist_script(&self) -> bool
pub fn persist_script(&self) -> bool
Specifies whether the compiled script should be persisted.
Sourcepub fn execution_context_id(&self) -> Option<&ExecutionContextId>
pub fn execution_context_id(&self) -> Option<&ExecutionContextId>
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.