Available on crate feature
Security only.Expand description
Security
Structs
- Certificate
Error Event Deprecated - There is a certificate error. If overriding certificate errors is enabled, then it should be
handled with the
handleCertificateErrorcommand. Note: this event does not fire if the certificate error has been allowed internally. Only one client per target should override certificate errors at the same time. - Certificate
Id - An internal certificate ID value.
- Certificate
Security State experimental - Details about the security state of the page certificate.
- Certificate
Security State Builder experimental - Disable
Command - Disables tracking security state changes.
- Disable
Return - Disables tracking security state changes.
- Enable
Command - Enables tracking security state changes.
- Enable
Return - Enables tracking security state changes.
- Handle
Certificate Error Command Deprecated - Handles a certificate error that fired a certificateError event.
- Handle
Certificate Error Return Deprecated - Handles a certificate error that fired a certificateError event.
- Insecure
Content Status Deprecated - Information about insecure content on the page.
- Insecure
Content Status Builder Deprecated - Safety
TipInfo experimental - Security
State Changed Event - The security state of the page changed.
- Security
State Changed Event Builder - Security
State Explanation - An explanation of an factor contributing to the security state.
- Security
State Explanation Builder - SetIgnore
Certificate Errors Command experimental - Enable/disable whether all certificate errors should be ignored.
- SetIgnore
Certificate Errors Return experimental - Enable/disable whether all certificate errors should be ignored.
- SetOverride
Certificate Errors Command Deprecated - Enable/disable overriding certificate errors. If enabled, all certificate error events need to
be handled by the DevTools client and should be answered with
handleCertificateErrorcommands. - SetOverride
Certificate Errors Return Deprecated - Enable/disable overriding certificate errors. If enabled, all certificate error events need to
be handled by the DevTools client and should be answered with
handleCertificateErrorcommands. - Visible
Security State experimental - Security state information about the page.
- Visible
Security State Builder experimental - Visible
Security State Changed Event experimental - The security state of the page changed.