Module chrome_remote_interface_model::security [−][src]
Security only.Security
Structs
| CertificateErrorEvent | Deprecated There is a certificate error. If overriding certificate errors is enabled, then it should be
handled with the |
| CertificateId | An internal certificate ID value. |
| CertificateSecurityState | experimentalDetails about the security state of the page certificate. |
| CertificateSecurityStateBuilder | experimental |
| DisableCommand | Disables tracking security state changes. |
| DisableReturn | Disables tracking security state changes. |
| EnableCommand | Enables tracking security state changes. |
| EnableReturn | Enables tracking security state changes. |
| HandleCertificateErrorCommand | Deprecated Handles a certificate error that fired a certificateError event. |
| HandleCertificateErrorReturn | Deprecated Handles a certificate error that fired a certificateError event. |
| InsecureContentStatus | Deprecated Information about insecure content on the page. |
| InsecureContentStatusBuilder | Deprecated |
| SafetyTipInfo | experimental |
| SecurityStateChangedEvent | The security state of the page changed. |
| SecurityStateChangedEventBuilder | |
| SecurityStateExplanation | An explanation of an factor contributing to the security state. |
| SecurityStateExplanationBuilder | |
| SetIgnoreCertificateErrorsCommand | experimentalEnable/disable whether all certificate errors should be ignored. |
| SetIgnoreCertificateErrorsReturn | experimentalEnable/disable whether all certificate errors should be ignored. |
| SetOverrideCertificateErrorsCommand | Deprecated Enable/disable overriding certificate errors. If enabled, all certificate error events need to
be handled by the DevTools client and should be answered with |
| SetOverrideCertificateErrorsReturn | Deprecated Enable/disable overriding certificate errors. If enabled, all certificate error events need to
be handled by the DevTools client and should be answered with |
| VisibleSecurityState | experimentalSecurity state information about the page. |
| VisibleSecurityStateBuilder | experimental |
| VisibleSecurityStateChangedEvent | experimentalThe security state of the page changed. |
Enums
| CertificateErrorAction | |
| MixedContentType | |
| SafetyTipStatus | experimental |
| SecurityState |